"""Store configuration."""

__all__ = ["PATH"]

import pathlib

home = pathlib.Path.home()
cwd = pathlib.Path.cwd()
cwd_config = cwd / "config.yml"

home_config = home / ".config" / "sky130.yml"
config_dir = home / ".config"
config_dir.mkdir(exist_ok=True)
module_path = pathlib.Path(__file__).parent.absolute()
repo_path = module_path.parent


class Path:
    module = module_path
    repo = repo_path
    lyp = module_path / "klayout" / "sky130" / "layers.lyp"
    libs = module_path / "libs"

    libhd = libs / "sky130hd"
    libhs = libs / "sky130hs"
    libhvl = libs / "sky130hvl"

    gds = module_path / "gds"
    gdshd = libhd / "gds" / "sky130_fd_sc_hd.gds"
    gdshs = libhs / "gds" / "sky130_fd_sc_hs.gds"
    gdshvl = libhvl / "gds" / "sky130_fd_sc_hvl.gds"


PATH = Path()

if __name__ == "__main__":
    print(PATH)



"""sky130 - skywater gdsfactory pdk"""
import pathlib

from gdsfactory.config import logger
from gdsfactory.get_factories import get_cells
from gdsfactory.pdk import Pdk

from sky130 import components
from sky130.config import module_path
from sky130.layers import LAYER
from sky130.tech import cross_sections

__version__ = "0.0.10"

cells = get_cells(components)
PDK = Pdk(
    name="sky130", cells=cells, cross_sections=cross_sections, layers=LAYER.dict()
)
PDK.register_cells_yaml(dirpath=pathlib.Path(__file__).parent.absolute())
PDK.activate()

logger.info(f"load sky130 PDK {__version__!r} installed at {str(module_path)!r}")

__all__ = ["cells", "PDK"]

if __name__ == "__main__":
    f = PDK.cells
    print(f.keys())



from gdsfactory.layers import lyp_to_dataclass
from gdsfactory.types import Layer
from pydantic import BaseModel

from sky130.config import PATH


class LayerMap(BaseModel):
    areaidanalog: Layer = (81, 79)
    areaidcore: Layer = (81, 2)
    areaidcritCorner: Layer = (81, 51)
    areaidcritSid: Layer = (81, 52)
    areaiddeadZon: Layer = (81, 50)
    areaiddieCut: Layer = (81, 11)
    areaiddiode: Layer = (81, 23)
    areaidesd: Layer = (81, 19)
    areaidetest: Layer = (81, 101)
    areaidextendedDrain: Layer = (81, 57)
    areaidframe: Layer = (81, 3)
    areaidframeRect: Layer = (81, 12)
    areaidhvnwell: Layer = (81, 63)
    areaidinjection: Layer = (81, 17)
    areaidlowTapDensity: Layer = (81, 14)
    areaidlvNative: Layer = (81, 60)
    areaidmoduleCut: Layer = (81, 10)
    areaidnotCritSide: Layer = (81, 15)
    areaidopcDrop: Layer = (81, 54)
    areaidphoto: Layer = (81, 81)
    areaidrdlprobepad: Layer = (81, 27)
    areaidrfdiode: Layer = (81, 125)
    areaidseal: Layer = (81, 1)
    areaidsigPadDiff: Layer = (81, 6)
    areaidsigPadMetNtr: Layer = (81, 8)
    areaidsigPadWell: Layer = (81, 7)
    areaidstandardc: Layer = (81, 4)
    areaidsubstrateCut: Layer = (81, 53)
    areaidwaffleWindow: Layer = (81, 13)
    blankingdrawing: Layer = (124, 40)
    bumpdrawing: Layer = (127, 22)
    capacitordrawing: Layer = (82, 64)
    cbumpmask: Layer = (101, 0)
    cctm1drawing: Layer = (101, 44)
    cctm1mask: Layer = (35, 0)
    cctm1maskAdd: Layer = (101, 43)
    cctm1maskDrop: Layer = (101, 42)
    ccu1mmask: Layer = (93, 0)
    cdnmdrawing: Layer = (110, 20)
    cdnmmask: Layer = (48, 0)
    cdnmmaskAdd: Layer = (110, 21)
    cdnmmaskDrop: Layer = (110, 22)
    cfomdrawing: Layer = (22, 20)
    cfommask: Layer = (23, 0)
    cfommaskAdd: Layer = (22, 21)
    cfommaskDrop: Layer = (22, 22)
    cfomwaffleDrop: Layer = (22, 24)
    chvntmdrawing: Layer = (38, 20)
    chvntmmask: Layer = (39, 0)
    chvntmmaskAdd: Layer = (38, 21)
    chvntmmaskDrop: Layer = (38, 22)
    chvtpmdrawing: Layer = (88, 44)
    chvtpmmask: Layer = (97, 0)
    chvtpmmaskAdd: Layer = (97, 43)
    chvtpmmaskDrop: Layer = (97, 42)
    chvtrmdrawing: Layer = (98, 44)
    chvtrmmask: Layer = (98, 0)
    chvtrmmaskAdd: Layer = (98, 43)
    chvtrmmaskDrop: Layer = (98, 42)
    cldntmdrawing: Layer = (11, 20)
    cldntmmask: Layer = (11, 0)
    cli1mdrawing: Layer = (115, 44)
    cli1mmask: Layer = (56, 0)
    cli1mmaskAdd: Layer = (115, 43)
    cli1mmaskDrop: Layer = (115, 42)
    clicm1drawing: Layer = (106, 44)
    clicm1mask: Layer = (43, 0)
    clicm1maskAdd: Layer = (106, 43)
    clicm1maskDrop: Layer = (106, 42)
    clvomdrawing: Layer = (45, 20)
    clvommask: Layer = (46, 0)
    clvommaskAdd: Layer = (45, 21)
    clvommaskDrop: Layer = (45, 22)
    clvtnmdrawing: Layer = (25, 44)
    clvtnmmask: Layer = (25, 0)
    clvtnmmaskAdd: Layer = (25, 43)
    clvtnmmaskDrop: Layer = (25, 42)
    cmm1drawing: Layer = (62, 20)
    cmm1mask: Layer = (36, 0)
    cmm1maskAdd: Layer = (62, 21)
    cmm1maskDrop: Layer = (62, 22)
    cmm1waffleDrop: Layer = (62, 24)
    cmm2drawing: Layer = (105, 44)
    cmm2mask: Layer = (41, 0)
    cmm2maskAdd: Layer = (105, 43)
    cmm2maskDrop: Layer = (105, 42)
    cmm2waffleDrop: Layer = (105, 52)
    cmm3drawing: Layer = (107, 20)
    cmm3mask: Layer = (34, 0)
    cmm3maskAdd: Layer = (107, 21)
    cmm3maskDrop: Layer = (107, 22)
    cmm3waffleDrop: Layer = (107, 24)
    cmm4mask: Layer = (51, 0)
    cmm4maskAdd: Layer = (112, 43)
    cmm4maskDrop: Layer = (112, 42)
    cmm4waffleDrop: Layer = (112, 4)
    cmm5mask: Layer = (59, 0)
    cmm5waffleDrop: Layer = (117, 4)
    cncmdrawing: Layer = (96, 44)
    cncmmask: Layer = (17, 0)
    cnpcdrawing: Layer = (44, 20)
    cnpcmask: Layer = (49, 0)
    cnpcmaskAdd: Layer = (44, 43)
    cnpcmaskDrop: Layer = (44, 42)
    cnsdmdrawing: Layer = (29, 20)
    cnsdmmask: Layer = (30, 0)
    cnsdmmaskAdd: Layer = (29, 21)
    cnsdmmaskDrop: Layer = (29, 22)
    cnsmmask: Layer = (22, 0)
    cntmdrawing: Layer = (26, 20)
    cntmmask: Layer = (27, 0)
    cntmmaskAdd: Layer = (26, 21)
    cntmmaskDrop: Layer = (26, 22)
    cnwmdrawing: Layer = (109, 44)
    cnwmmask: Layer = (21, 0)
    cnwmmaskAdd: Layer = (109, 43)
    cnwmmaskDrop: Layer = (109, 42)
    conomdrawing: Layer = (87, 44)
    conommask: Layer = (88, 0)
    conommaskAdd: Layer = (87, 43)
    conommaskDrop: Layer = (87, 42)
    cp1mdrawing: Layer = (33, 44)
    cp1mmask: Layer = (28, 0)
    cp1mmaskAdd: Layer = (33, 43)
    cp1mmaskDrop: Layer = (33, 42)
    cp1mwaffleDrop: Layer = (33, 24)
    cpbomask: Layer = (99, 0)
    cpdmdrawing: Layer = (104, 44)
    cpdmmask: Layer = (37, 0)
    cpdmmaskAdd: Layer = (104, 43)
    cpdmmaskDrop: Layer = (104, 42)
    cpmm2mask: Layer = (94, 0)
    cpmmdrawing: Layer = (91, 44)
    cpsdmdrawing: Layer = (31, 20)
    cpsdmmask: Layer = (32, 0)
    cpsdmmaskAdd: Layer = (31, 21)
    cpsdmmaskDrop: Layer = (31, 22)
    crpmdrawing: Layer = (53, 44)
    crpmmask: Layer = (96, 0)
    crpmmaskAdd: Layer = (53, 43)
    crpmmaskDrop: Layer = (53, 42)
    crrpmmask: Layer = (102, 0)
    ctunmdrawing: Layer = (96, 20)
    ctunmmask: Layer = (20, 0)
    ctunmmaskAdd: Layer = (96, 21)
    ctunmmaskDrop: Layer = (96, 22)
    cubmmask: Layer = (100, 0)
    cviam2drawing: Layer = (108, 20)
    cviam2mask: Layer = (44, 0)
    cviam2maskAdd: Layer = (108, 21)
    cviam2maskDrop: Layer = (108, 22)
    cviam3drawing: Layer = (112, 20)
    cviam3mask: Layer = (50, 0)
    cviam3maskAdd: Layer = (112, 21)
    cviam3maskDrop: Layer = (112, 22)
    cviam4drawing: Layer = (117, 20)
    cviam4mask: Layer = (58, 0)
    cviam4maskAdd: Layer = (117, 21)
    cviam4maskDrop: Layer = (117, 22)
    cviamdrawing: Layer = (105, 20)
    cviammask: Layer = (40, 0)
    cviammaskAdd: Layer = (105, 21)
    cviammaskDrop: Layer = (105, 22)
    diffboundary: Layer = (65, 4)
    diffcut: Layer = (65, 14)
    diffdrawing: Layer = (65, 20)
    diffhv: Layer = (65, 8)
    difflabel: Layer = (65, 6)
    diffnet: Layer = (65, 23)
    diffpin: Layer = (65, 16)
    diffres: Layer = (65, 13)
    dnwelldrawing: Layer = (64, 18)
    fomdummy: Layer = (22, 23)
    hvidrawing: Layer = (75, 20)
    hvntmdrawing: Layer = (125, 20)
    hvtpdrawing: Layer = (78, 44)
    hvtrdrawing: Layer = (18, 20)
    inductordrawing: Layer = (82, 24)
    inductorlabel: Layer = (82, 25)
    inductorterm1: Layer = (82, 26)
    inductorterm2: Layer = (82, 27)
    inductorterm3: Layer = (82, 28)
    ldntmdrawing: Layer = (11, 44)
    li1blockage: Layer = (67, 10)
    li1boundary: Layer = (67, 4)
    li1cut: Layer = (67, 14)
    li1drawing: Layer = (67, 20)
    li1label: Layer = (67, 5)
    li1net: Layer = (67, 23)
    li1pin: Layer = (67, 16)
    li1probe: Layer = (67, 25)
    li1res: Layer = (67, 13)
    li1short: Layer = (67, 15)
    licon1boundary: Layer = (66, 60)
    licon1drawing: Layer = (66, 44)
    licon1net: Layer = (66, 41)
    licon1pin: Layer = (66, 58)
    lvtndrawing: Layer = (125, 44)
    markererror: Layer = (83, 6)
    markerwarning: Layer = (83, 7)
    mconboundary: Layer = (67, 60)
    mcondrawing: Layer = (67, 44)
    mconnet: Layer = (67, 41)
    mconpin: Layer = (67, 48)
    met1blockage: Layer = (68, 10)
    met1boundary: Layer = (68, 4)
    met1cut: Layer = (68, 14)
    met1drawing: Layer = (68, 20)
    met1label: Layer = (68, 5)
    met1net: Layer = (68, 23)
    met1option1: Layer = (68, 32)
    met1option2: Layer = (68, 33)
    met1option3: Layer = (68, 34)
    met1option4: Layer = (68, 35)
    met1option5: Layer = (68, 36)
    met1option6: Layer = (68, 37)
    met1option7: Layer = (68, 38)
    met1option8: Layer = (68, 39)
    met1pin: Layer = (68, 16)
    met1probe: Layer = (68, 25)
    met1psa1: Layer = (68, 88)
    met1psa2: Layer = (68, 89)
    met1psa3: Layer = (68, 90)
    met1psa4: Layer = (68, 91)
    met1psa5: Layer = (68, 92)
    met1psa6: Layer = (68, 93)
    met1res: Layer = (68, 13)
    met1short: Layer = (68, 15)
    met2blockage: Layer = (69, 10)
    met2boundary: Layer = (69, 4)
    met2cut: Layer = (69, 14)
    met2drawing: Layer = (69, 20)
    met2label: Layer = (69, 5)
    met2net: Layer = (69, 23)
    met2option1: Layer = (69, 32)
    met2option2: Layer = (69, 33)
    met2option3: Layer = (69, 34)
    met2option4: Layer = (69, 35)
    met2option5: Layer = (69, 36)
    met2option6: Layer = (69, 37)
    met2option7: Layer = (69, 38)
    met2option8: Layer = (69, 39)
    met2pin: Layer = (69, 16)
    met2probe: Layer = (69, 25)
    met2psa1: Layer = (69, 88)
    met2psa2: Layer = (69, 89)
    met2psa3: Layer = (69, 90)
    met2psa4: Layer = (69, 91)
    met2psa5: Layer = (69, 92)
    met2psa6: Layer = (69, 93)
    met2res: Layer = (69, 13)
    met2short: Layer = (69, 15)
    met3blockage: Layer = (70, 10)
    met3boundary: Layer = (70, 4)
    met3cut: Layer = (70, 14)
    met3drawing: Layer = (70, 20)
    met3fuse: Layer = (70, 17)
    met3label: Layer = (70, 5)
    met3net: Layer = (70, 23)
    met3option1: Layer = (70, 32)
    met3option2: Layer = (70, 33)
    met3option3: Layer = (70, 34)
    met3option4: Layer = (70, 35)
    met3option5: Layer = (70, 36)
    met3option6: Layer = (70, 37)
    met3option7: Layer = (70, 38)
    met3option8: Layer = (70, 39)
    met3pin: Layer = (70, 16)
    met3probe: Layer = (70, 25)
    met3psa1: Layer = (70, 88)
    met3psa2: Layer = (70, 89)
    met3psa3: Layer = (70, 90)
    met3psa4: Layer = (70, 91)
    met3psa5: Layer = (70, 92)
    met3psa6: Layer = (70, 93)
    met3res: Layer = (70, 13)
    met3short: Layer = (70, 15)
    met4blockage: Layer = (71, 10)
    met4boundary: Layer = (71, 4)
    met4cut: Layer = (71, 14)
    met4drawing: Layer = (71, 20)
    met4fuse: Layer = (71, 17)
    met4label: Layer = (71, 5)
    met4net: Layer = (71, 23)
    met4option1: Layer = (71, 32)
    met4option2: Layer = (71, 33)
    met4option3: Layer = (71, 34)
    met4option4: Layer = (71, 35)
    met4option5: Layer = (71, 36)
    met4option6: Layer = (71, 37)
    met4option7: Layer = (71, 38)
    met4option8: Layer = (71, 39)
    met4pin: Layer = (71, 16)
    met4probe: Layer = (71, 25)
    met4psa1: Layer = (71, 88)
    met4psa2: Layer = (71, 89)
    met4psa3: Layer = (71, 90)
    met4psa4: Layer = (71, 91)
    met4psa5: Layer = (71, 92)
    met4psa6: Layer = (71, 93)
    met4res: Layer = (71, 13)
    met4short: Layer = (71, 15)
    met5blockage: Layer = (72, 10)
    met5boundary: Layer = (72, 4)
    met5cut: Layer = (72, 14)
    met5drawing: Layer = (72, 20)
    met5fuse: Layer = (72, 17)
    met5label: Layer = (72, 5)
    met5net: Layer = (72, 23)
    met5option1: Layer = (72, 32)
    met5option2: Layer = (72, 33)
    met5option3: Layer = (72, 34)
    met5option4: Layer = (72, 35)
    met5option5: Layer = (72, 36)
    met5option6: Layer = (72, 37)
    met5option7: Layer = (72, 38)
    met5option8: Layer = (72, 39)
    met5pin: Layer = (72, 16)
    met5probe: Layer = (72, 25)
    met5psa1: Layer = (72, 88)
    met5psa2: Layer = (72, 89)
    met5psa3: Layer = (72, 90)
    met5psa4: Layer = (72, 91)
    met5psa5: Layer = (72, 92)
    met5psa6: Layer = (72, 93)
    met5res: Layer = (72, 13)
    met5short: Layer = (72, 15)
    ncmdrawing: Layer = (92, 44)
    npcdrawing: Layer = (95, 20)
    npndrawing: Layer = (82, 20)
    npnlabel: Layer = (82, 5)
    nsdmdrawing: Layer = (93, 44)
    nsmdrawing: Layer = (61, 20)
    nwelldrawing: Layer = (64, 20)
    nwelllabel: Layer = (64, 5)
    nwellnet: Layer = (84, 23)
    nwellpin: Layer = (64, 16)
    overlapboundary: Layer = (90, 4)
    overlapdrawing: Layer = (90, 20)
    padCenterdrawing: Layer = (81, 20)
    paddrawing: Layer = (76, 20)
    padlabel: Layer = (76, 5)
    padpin: Layer = (76, 16)
    pmm2drawing: Layer = (77, 20)
    pmmdrawing: Layer = (85, 44)
    pnpdrawing: Layer = (82, 44)
    pnplabel: Layer = (82, 59)
    polyboundary: Layer = (66, 4)
    polycut: Layer = (66, 14)
    polydrawing: Layer = (66, 20)
    polygate: Layer = (66, 9)
    polylabel: Layer = (66, 5)
    polymodel: Layer = (66, 83)
    polynet: Layer = (66, 23)
    polypin: Layer = (66, 16)
    polyprobe: Layer = (66, 25)
    polyres: Layer = (66, 13)
    polyshort: Layer = (66, 15)
    prBoundaryboundary: Layer = (235, 4)
    prBoundarydrawing: Layer = (235, 0)
    prunedrawing: Layer = (84, 44)
    psdmdrawing: Layer = (94, 20)
    pwellcut: Layer = (64, 14)
    pwelldrawing: Layer = (64, 44)
    pwellisolabel: Layer = (44, 5)
    pwellisopin: Layer = (44, 16)
    pwelllabel: Layer = (64, 59)
    pwellpin: Layer = (122, 16)
    pwellres: Layer = (64, 13)
    rdlcondrawing: Layer = (13, 0)
    rdlcut: Layer = (74, 14)
    rdldrawing: Layer = (74, 20)
    rdllabel: Layer = (74, 5)
    rdloption1: Layer = (89, 32)
    rdloption2: Layer = (89, 33)
    rdloption3: Layer = (89, 34)
    rdloption4: Layer = (89, 35)
    rdloption5: Layer = (89, 36)
    rdloption6: Layer = (89, 37)
    rdloption7: Layer = (89, 38)
    rdloption8: Layer = (89, 39)
    rdlpin: Layer = (74, 16)
    rdlpsa1: Layer = (74, 88)
    rdlpsa2: Layer = (74, 89)
    rdlpsa3: Layer = (74, 90)
    rdlpsa4: Layer = (74, 91)
    rdlpsa5: Layer = (74, 92)
    rdlpsa6: Layer = (74, 93)
    rdlres: Layer = (74, 13)
    rdlshort: Layer = (74, 15)
    rpmdrawing: Layer = (86, 20)
    rrpmdrawing: Layer = (102, 20)
    tapboundary: Layer = (65, 60)
    tapdrawing: Layer = (65, 44)
    taplabel: Layer = (65, 5)
    tapnet: Layer = (65, 41)
    tappin: Layer = (65, 48)
    targetdrawing: Layer = (76, 44)
    textdrawing: Layer = (83, 44)
    tunmdrawing: Layer = (80, 20)
    ubmdrawing: Layer = (127, 21)
    vhvidrawing: Layer = (74, 21)
    via2blockage: Layer = (7, 3)
    via2boundary: Layer = (69, 60)
    via2drawing: Layer = (69, 44)
    via2net: Layer = (69, 41)
    via2pin: Layer = (69, 58)
    via3blockage: Layer = (9, 3)
    via3boundary: Layer = (70, 60)
    via3drawing: Layer = (70, 44)
    via3label: Layer = (9, 1)
    via3net: Layer = (70, 41)
    via3pin: Layer = (70, 48)
    via4blockage: Layer = (11, 3)
    via4boundary: Layer = (71, 60)
    via4drawing: Layer = (71, 44)
    via4label: Layer = (11, 1)
    via4net: Layer = (71, 41)
    via4pin: Layer = (71, 48)
    viablockage: Layer = (5, 3)
    viaboundary: Layer = (68, 60)
    viadrawing: Layer = (68, 44)
    vialabel: Layer = (5, 1)
    vianet: Layer = (68, 41)
    viapin: Layer = (68, 58)

    LABEL_INSTANCE: Layer = (66, 0)
    DEVREC: Layer = (68, 0)
    PORT: Layer = (1, 10)
    PORTE: Layer = (1, 11)
    TE: Layer = (203, 0)
    TM: Layer = (204, 0)
    TEXT: Layer = (66, 0)

    class Config:
        frozen = True
        extra = "forbid"


LAYER = LayerMap()


if __name__ == "__main__":
    print(PATH.lyp)
    print(lyp_to_dataclass(PATH.lyp))



from functools import partial

import gdsfactory as gf

from sky130.config import PATH
from sky130.layers import LAYER

# add_ports_m1 = gf.partial(
#     gf.add_ports.add_ports_from_markers_inside,
#     pin_layer=LAYER.met1pin,
#     port_layer=LAYER.met1drawing,
#     port_type="electrical",
# )
# add_ports_m2 = gf.partial(
#     gf.add_ports.add_ports_from_markers_inside,
#     pin_layer=LAYER.met2pin,
#     port_layer=LAYER.met2drawing,
#     port_type="electrical",
# )

add_ports_m1 = gf.partial(
    gf.add_ports.add_ports_from_labels,
    port_layer=LAYER.met1drawing,
    layer_label=LAYER.met1label,
    port_type="electrical",
    port_width=0.2,
    get_name_from_label=True,
    guess_port_orientation=False,
)
add_ports_m2 = gf.partial(
    gf.add_ports.add_ports_from_labels,
    port_layer=LAYER.met2drawing,
    layer_label=LAYER.met2label,
    port_type="electrical",
    port_width=0.2,
    get_name_from_label=True,
    guess_port_orientation=False,
)
add_ports = gf.compose(add_ports_m1, add_ports_m2)

gdsdir = PATH.gds

import_gds = partial(gf.import_gds, gdsdir=gdsdir, decorator=add_ports)

sky130_fd_sc_hd__a2111o_1 = partial(import_gds, "sky130_fd_sc_hd__a2111o_1.gds")
sky130_fd_sc_hd__a2111o_2 = partial(import_gds, "sky130_fd_sc_hd__a2111o_2.gds")
sky130_fd_sc_hd__a2111o_4 = partial(import_gds, "sky130_fd_sc_hd__a2111o_4.gds")
sky130_fd_sc_hd__a2111oi_0 = partial(import_gds, "sky130_fd_sc_hd__a2111oi_0.gds")
sky130_fd_sc_hd__a2111oi_1 = partial(import_gds, "sky130_fd_sc_hd__a2111oi_1.gds")
sky130_fd_sc_hd__a2111oi_2 = partial(import_gds, "sky130_fd_sc_hd__a2111oi_2.gds")
sky130_fd_sc_hd__a2111oi_4 = partial(import_gds, "sky130_fd_sc_hd__a2111oi_4.gds")
sky130_fd_sc_hd__a211o_1 = partial(import_gds, "sky130_fd_sc_hd__a211o_1.gds")
sky130_fd_sc_hd__a211o_2 = partial(import_gds, "sky130_fd_sc_hd__a211o_2.gds")
sky130_fd_sc_hd__a211o_4 = partial(import_gds, "sky130_fd_sc_hd__a211o_4.gds")
sky130_fd_sc_hd__a211oi_1 = partial(import_gds, "sky130_fd_sc_hd__a211oi_1.gds")
sky130_fd_sc_hd__a211oi_2 = partial(import_gds, "sky130_fd_sc_hd__a211oi_2.gds")
sky130_fd_sc_hd__a211oi_4 = partial(import_gds, "sky130_fd_sc_hd__a211oi_4.gds")
sky130_fd_sc_hd__a21bo_1 = partial(import_gds, "sky130_fd_sc_hd__a21bo_1.gds")
sky130_fd_sc_hd__a21bo_2 = partial(import_gds, "sky130_fd_sc_hd__a21bo_2.gds")
sky130_fd_sc_hd__a21bo_4 = partial(import_gds, "sky130_fd_sc_hd__a21bo_4.gds")
sky130_fd_sc_hd__a21boi_0 = partial(import_gds, "sky130_fd_sc_hd__a21boi_0.gds")
sky130_fd_sc_hd__a21boi_1 = partial(import_gds, "sky130_fd_sc_hd__a21boi_1.gds")
sky130_fd_sc_hd__a21boi_2 = partial(import_gds, "sky130_fd_sc_hd__a21boi_2.gds")
sky130_fd_sc_hd__a21boi_4 = partial(import_gds, "sky130_fd_sc_hd__a21boi_4.gds")
sky130_fd_sc_hd__a21o_1 = partial(import_gds, "sky130_fd_sc_hd__a21o_1.gds")
sky130_fd_sc_hd__a21o_2 = partial(import_gds, "sky130_fd_sc_hd__a21o_2.gds")
sky130_fd_sc_hd__a21o_4 = partial(import_gds, "sky130_fd_sc_hd__a21o_4.gds")
sky130_fd_sc_hd__a21oi_1 = partial(import_gds, "sky130_fd_sc_hd__a21oi_1.gds")
sky130_fd_sc_hd__a21oi_2 = partial(import_gds, "sky130_fd_sc_hd__a21oi_2.gds")
sky130_fd_sc_hd__a21oi_4 = partial(import_gds, "sky130_fd_sc_hd__a21oi_4.gds")
sky130_fd_sc_hd__a221o_1 = partial(import_gds, "sky130_fd_sc_hd__a221o_1.gds")
sky130_fd_sc_hd__a221o_2 = partial(import_gds, "sky130_fd_sc_hd__a221o_2.gds")
sky130_fd_sc_hd__a221o_4 = partial(import_gds, "sky130_fd_sc_hd__a221o_4.gds")
sky130_fd_sc_hd__a221oi_1 = partial(import_gds, "sky130_fd_sc_hd__a221oi_1.gds")
sky130_fd_sc_hd__a221oi_2 = partial(import_gds, "sky130_fd_sc_hd__a221oi_2.gds")
sky130_fd_sc_hd__a221oi_4 = partial(import_gds, "sky130_fd_sc_hd__a221oi_4.gds")
sky130_fd_sc_hd__a222oi_1 = partial(import_gds, "sky130_fd_sc_hd__a222oi_1.gds")
sky130_fd_sc_hd__a22o_1 = partial(import_gds, "sky130_fd_sc_hd__a22o_1.gds")
sky130_fd_sc_hd__a22o_2 = partial(import_gds, "sky130_fd_sc_hd__a22o_2.gds")
sky130_fd_sc_hd__a22o_4 = partial(import_gds, "sky130_fd_sc_hd__a22o_4.gds")
sky130_fd_sc_hd__a22oi_1 = partial(import_gds, "sky130_fd_sc_hd__a22oi_1.gds")
sky130_fd_sc_hd__a22oi_2 = partial(import_gds, "sky130_fd_sc_hd__a22oi_2.gds")
sky130_fd_sc_hd__a22oi_4 = partial(import_gds, "sky130_fd_sc_hd__a22oi_4.gds")
sky130_fd_sc_hd__a2bb2o_1 = partial(import_gds, "sky130_fd_sc_hd__a2bb2o_1.gds")
sky130_fd_sc_hd__a2bb2o_2 = partial(import_gds, "sky130_fd_sc_hd__a2bb2o_2.gds")
sky130_fd_sc_hd__a2bb2o_4 = partial(import_gds, "sky130_fd_sc_hd__a2bb2o_4.gds")
sky130_fd_sc_hd__a2bb2oi_1 = partial(import_gds, "sky130_fd_sc_hd__a2bb2oi_1.gds")
sky130_fd_sc_hd__a2bb2oi_2 = partial(import_gds, "sky130_fd_sc_hd__a2bb2oi_2.gds")
sky130_fd_sc_hd__a2bb2oi_4 = partial(import_gds, "sky130_fd_sc_hd__a2bb2oi_4.gds")
sky130_fd_sc_hd__a311o_1 = partial(import_gds, "sky130_fd_sc_hd__a311o_1.gds")
sky130_fd_sc_hd__a311o_2 = partial(import_gds, "sky130_fd_sc_hd__a311o_2.gds")
sky130_fd_sc_hd__a311o_4 = partial(import_gds, "sky130_fd_sc_hd__a311o_4.gds")
sky130_fd_sc_hd__a311oi_1 = partial(import_gds, "sky130_fd_sc_hd__a311oi_1.gds")
sky130_fd_sc_hd__a311oi_2 = partial(import_gds, "sky130_fd_sc_hd__a311oi_2.gds")
sky130_fd_sc_hd__a311oi_4 = partial(import_gds, "sky130_fd_sc_hd__a311oi_4.gds")
sky130_fd_sc_hd__a31o_1 = partial(import_gds, "sky130_fd_sc_hd__a31o_1.gds")
sky130_fd_sc_hd__a31o_2 = partial(import_gds, "sky130_fd_sc_hd__a31o_2.gds")
sky130_fd_sc_hd__a31o_4 = partial(import_gds, "sky130_fd_sc_hd__a31o_4.gds")
sky130_fd_sc_hd__a31oi_1 = partial(import_gds, "sky130_fd_sc_hd__a31oi_1.gds")
sky130_fd_sc_hd__a31oi_2 = partial(import_gds, "sky130_fd_sc_hd__a31oi_2.gds")
sky130_fd_sc_hd__a31oi_4 = partial(import_gds, "sky130_fd_sc_hd__a31oi_4.gds")
sky130_fd_sc_hd__a32o_1 = partial(import_gds, "sky130_fd_sc_hd__a32o_1.gds")
sky130_fd_sc_hd__a32o_2 = partial(import_gds, "sky130_fd_sc_hd__a32o_2.gds")
sky130_fd_sc_hd__a32o_4 = partial(import_gds, "sky130_fd_sc_hd__a32o_4.gds")
sky130_fd_sc_hd__a32oi_1 = partial(import_gds, "sky130_fd_sc_hd__a32oi_1.gds")
sky130_fd_sc_hd__a32oi_2 = partial(import_gds, "sky130_fd_sc_hd__a32oi_2.gds")
sky130_fd_sc_hd__a32oi_4 = partial(import_gds, "sky130_fd_sc_hd__a32oi_4.gds")
sky130_fd_sc_hd__a41o_1 = partial(import_gds, "sky130_fd_sc_hd__a41o_1.gds")
sky130_fd_sc_hd__a41o_2 = partial(import_gds, "sky130_fd_sc_hd__a41o_2.gds")
sky130_fd_sc_hd__a41o_4 = partial(import_gds, "sky130_fd_sc_hd__a41o_4.gds")
sky130_fd_sc_hd__a41oi_1 = partial(import_gds, "sky130_fd_sc_hd__a41oi_1.gds")
sky130_fd_sc_hd__a41oi_2 = partial(import_gds, "sky130_fd_sc_hd__a41oi_2.gds")
sky130_fd_sc_hd__a41oi_4 = partial(import_gds, "sky130_fd_sc_hd__a41oi_4.gds")
sky130_fd_sc_hd__and2_0 = partial(import_gds, "sky130_fd_sc_hd__and2_0.gds")
sky130_fd_sc_hd__and2_1 = partial(import_gds, "sky130_fd_sc_hd__and2_1.gds")
sky130_fd_sc_hd__and2_2 = partial(import_gds, "sky130_fd_sc_hd__and2_2.gds")
sky130_fd_sc_hd__and2_4 = partial(import_gds, "sky130_fd_sc_hd__and2_4.gds")
sky130_fd_sc_hd__and2b_1 = partial(import_gds, "sky130_fd_sc_hd__and2b_1.gds")
sky130_fd_sc_hd__and2b_2 = partial(import_gds, "sky130_fd_sc_hd__and2b_2.gds")
sky130_fd_sc_hd__and2b_4 = partial(import_gds, "sky130_fd_sc_hd__and2b_4.gds")
sky130_fd_sc_hd__and3_1 = partial(import_gds, "sky130_fd_sc_hd__and3_1.gds")
sky130_fd_sc_hd__and3_2 = partial(import_gds, "sky130_fd_sc_hd__and3_2.gds")
sky130_fd_sc_hd__and3_4 = partial(import_gds, "sky130_fd_sc_hd__and3_4.gds")
sky130_fd_sc_hd__and3b_1 = partial(import_gds, "sky130_fd_sc_hd__and3b_1.gds")
sky130_fd_sc_hd__and3b_2 = partial(import_gds, "sky130_fd_sc_hd__and3b_2.gds")
sky130_fd_sc_hd__and3b_4 = partial(import_gds, "sky130_fd_sc_hd__and3b_4.gds")
sky130_fd_sc_hd__and4_1 = partial(import_gds, "sky130_fd_sc_hd__and4_1.gds")
sky130_fd_sc_hd__and4_2 = partial(import_gds, "sky130_fd_sc_hd__and4_2.gds")
sky130_fd_sc_hd__and4_4 = partial(import_gds, "sky130_fd_sc_hd__and4_4.gds")
sky130_fd_sc_hd__and4b_1 = partial(import_gds, "sky130_fd_sc_hd__and4b_1.gds")
sky130_fd_sc_hd__and4b_2 = partial(import_gds, "sky130_fd_sc_hd__and4b_2.gds")
sky130_fd_sc_hd__and4b_4 = partial(import_gds, "sky130_fd_sc_hd__and4b_4.gds")
sky130_fd_sc_hd__and4bb_1 = partial(import_gds, "sky130_fd_sc_hd__and4bb_1.gds")
sky130_fd_sc_hd__and4bb_2 = partial(import_gds, "sky130_fd_sc_hd__and4bb_2.gds")
sky130_fd_sc_hd__and4bb_4 = partial(import_gds, "sky130_fd_sc_hd__and4bb_4.gds")
sky130_fd_sc_hd__buf_1 = partial(import_gds, "sky130_fd_sc_hd__buf_1.gds")
sky130_fd_sc_hd__buf_12 = partial(import_gds, "sky130_fd_sc_hd__buf_12.gds")
sky130_fd_sc_hd__buf_16 = partial(import_gds, "sky130_fd_sc_hd__buf_16.gds")
sky130_fd_sc_hd__buf_2 = partial(import_gds, "sky130_fd_sc_hd__buf_2.gds")
sky130_fd_sc_hd__buf_4 = partial(import_gds, "sky130_fd_sc_hd__buf_4.gds")
sky130_fd_sc_hd__buf_6 = partial(import_gds, "sky130_fd_sc_hd__buf_6.gds")
sky130_fd_sc_hd__buf_8 = partial(import_gds, "sky130_fd_sc_hd__buf_8.gds")
sky130_fd_sc_hd__bufbuf_16 = partial(import_gds, "sky130_fd_sc_hd__bufbuf_16.gds")
sky130_fd_sc_hd__bufbuf_8 = partial(import_gds, "sky130_fd_sc_hd__bufbuf_8.gds")
sky130_fd_sc_hd__bufinv_16 = partial(import_gds, "sky130_fd_sc_hd__bufinv_16.gds")
sky130_fd_sc_hd__bufinv_8 = partial(import_gds, "sky130_fd_sc_hd__bufinv_8.gds")
sky130_fd_sc_hd__clkbuf_1 = partial(import_gds, "sky130_fd_sc_hd__clkbuf_1.gds")
sky130_fd_sc_hd__clkbuf_16 = partial(import_gds, "sky130_fd_sc_hd__clkbuf_16.gds")
sky130_fd_sc_hd__clkbuf_2 = partial(import_gds, "sky130_fd_sc_hd__clkbuf_2.gds")
sky130_fd_sc_hd__clkbuf_4 = partial(import_gds, "sky130_fd_sc_hd__clkbuf_4.gds")
sky130_fd_sc_hd__clkbuf_8 = partial(import_gds, "sky130_fd_sc_hd__clkbuf_8.gds")
sky130_fd_sc_hd__clkdlybuf4s15_1 = partial(
    import_gds, "sky130_fd_sc_hd__clkdlybuf4s15_1.gds"
)
sky130_fd_sc_hd__clkdlybuf4s15_2 = partial(
    import_gds, "sky130_fd_sc_hd__clkdlybuf4s15_2.gds"
)
sky130_fd_sc_hd__clkdlybuf4s18_1 = partial(
    import_gds, "sky130_fd_sc_hd__clkdlybuf4s18_1.gds"
)
sky130_fd_sc_hd__clkdlybuf4s18_2 = partial(
    import_gds, "sky130_fd_sc_hd__clkdlybuf4s18_2.gds"
)
sky130_fd_sc_hd__clkdlybuf4s25_1 = partial(
    import_gds, "sky130_fd_sc_hd__clkdlybuf4s25_1.gds"
)
sky130_fd_sc_hd__clkdlybuf4s25_2 = partial(
    import_gds, "sky130_fd_sc_hd__clkdlybuf4s25_2.gds"
)
sky130_fd_sc_hd__clkdlybuf4s50_1 = partial(
    import_gds, "sky130_fd_sc_hd__clkdlybuf4s50_1.gds"
)
sky130_fd_sc_hd__clkdlybuf4s50_2 = partial(
    import_gds, "sky130_fd_sc_hd__clkdlybuf4s50_2.gds"
)
sky130_fd_sc_hd__clkinv_1 = partial(import_gds, "sky130_fd_sc_hd__clkinv_1.gds")
sky130_fd_sc_hd__clkinv_16 = partial(import_gds, "sky130_fd_sc_hd__clkinv_16.gds")
sky130_fd_sc_hd__clkinv_2 = partial(import_gds, "sky130_fd_sc_hd__clkinv_2.gds")
sky130_fd_sc_hd__clkinv_4 = partial(import_gds, "sky130_fd_sc_hd__clkinv_4.gds")
sky130_fd_sc_hd__clkinv_8 = partial(import_gds, "sky130_fd_sc_hd__clkinv_8.gds")
sky130_fd_sc_hd__clkinvlp_2 = partial(import_gds, "sky130_fd_sc_hd__clkinvlp_2.gds")
sky130_fd_sc_hd__clkinvlp_4 = partial(import_gds, "sky130_fd_sc_hd__clkinvlp_4.gds")
sky130_fd_sc_hd__conb_1 = partial(import_gds, "sky130_fd_sc_hd__conb_1.gds")
sky130_fd_sc_hd__decap_12 = partial(import_gds, "sky130_fd_sc_hd__decap_12.gds")
sky130_fd_sc_hd__decap_3 = partial(import_gds, "sky130_fd_sc_hd__decap_3.gds")
sky130_fd_sc_hd__decap_4 = partial(import_gds, "sky130_fd_sc_hd__decap_4.gds")
sky130_fd_sc_hd__decap_6 = partial(import_gds, "sky130_fd_sc_hd__decap_6.gds")
sky130_fd_sc_hd__decap_8 = partial(import_gds, "sky130_fd_sc_hd__decap_8.gds")
sky130_fd_sc_hd__dfbbn_1 = partial(import_gds, "sky130_fd_sc_hd__dfbbn_1.gds")
sky130_fd_sc_hd__dfbbn_2 = partial(import_gds, "sky130_fd_sc_hd__dfbbn_2.gds")
sky130_fd_sc_hd__dfbbp_1 = partial(import_gds, "sky130_fd_sc_hd__dfbbp_1.gds")
sky130_fd_sc_hd__dfrbp_1 = partial(import_gds, "sky130_fd_sc_hd__dfrbp_1.gds")
sky130_fd_sc_hd__dfrbp_2 = partial(import_gds, "sky130_fd_sc_hd__dfrbp_2.gds")
sky130_fd_sc_hd__dfrtn_1 = partial(import_gds, "sky130_fd_sc_hd__dfrtn_1.gds")
sky130_fd_sc_hd__dfrtp_1 = partial(import_gds, "sky130_fd_sc_hd__dfrtp_1.gds")
sky130_fd_sc_hd__dfrtp_2 = partial(import_gds, "sky130_fd_sc_hd__dfrtp_2.gds")
sky130_fd_sc_hd__dfrtp_4 = partial(import_gds, "sky130_fd_sc_hd__dfrtp_4.gds")
sky130_fd_sc_hd__dfsbp_1 = partial(import_gds, "sky130_fd_sc_hd__dfsbp_1.gds")
sky130_fd_sc_hd__dfsbp_2 = partial(import_gds, "sky130_fd_sc_hd__dfsbp_2.gds")
sky130_fd_sc_hd__dfstp_1 = partial(import_gds, "sky130_fd_sc_hd__dfstp_1.gds")
sky130_fd_sc_hd__dfstp_2 = partial(import_gds, "sky130_fd_sc_hd__dfstp_2.gds")
sky130_fd_sc_hd__dfstp_4 = partial(import_gds, "sky130_fd_sc_hd__dfstp_4.gds")
sky130_fd_sc_hd__dfxbp_1 = partial(import_gds, "sky130_fd_sc_hd__dfxbp_1.gds")
sky130_fd_sc_hd__dfxbp_2 = partial(import_gds, "sky130_fd_sc_hd__dfxbp_2.gds")
sky130_fd_sc_hd__dfxtp_1 = partial(import_gds, "sky130_fd_sc_hd__dfxtp_1.gds")
sky130_fd_sc_hd__dfxtp_2 = partial(import_gds, "sky130_fd_sc_hd__dfxtp_2.gds")
sky130_fd_sc_hd__dfxtp_4 = partial(import_gds, "sky130_fd_sc_hd__dfxtp_4.gds")
sky130_fd_sc_hd__diode_2 = partial(import_gds, "sky130_fd_sc_hd__diode_2.gds")
sky130_fd_sc_hd__dlclkp_1 = partial(import_gds, "sky130_fd_sc_hd__dlclkp_1.gds")
sky130_fd_sc_hd__dlclkp_2 = partial(import_gds, "sky130_fd_sc_hd__dlclkp_2.gds")
sky130_fd_sc_hd__dlclkp_4 = partial(import_gds, "sky130_fd_sc_hd__dlclkp_4.gds")
sky130_fd_sc_hd__dlrbn_1 = partial(import_gds, "sky130_fd_sc_hd__dlrbn_1.gds")
sky130_fd_sc_hd__dlrbn_2 = partial(import_gds, "sky130_fd_sc_hd__dlrbn_2.gds")
sky130_fd_sc_hd__dlrbp_1 = partial(import_gds, "sky130_fd_sc_hd__dlrbp_1.gds")
sky130_fd_sc_hd__dlrbp_2 = partial(import_gds, "sky130_fd_sc_hd__dlrbp_2.gds")
sky130_fd_sc_hd__dlrtn_1 = partial(import_gds, "sky130_fd_sc_hd__dlrtn_1.gds")
sky130_fd_sc_hd__dlrtn_2 = partial(import_gds, "sky130_fd_sc_hd__dlrtn_2.gds")
sky130_fd_sc_hd__dlrtn_4 = partial(import_gds, "sky130_fd_sc_hd__dlrtn_4.gds")
sky130_fd_sc_hd__dlrtp_1 = partial(import_gds, "sky130_fd_sc_hd__dlrtp_1.gds")
sky130_fd_sc_hd__dlrtp_2 = partial(import_gds, "sky130_fd_sc_hd__dlrtp_2.gds")
sky130_fd_sc_hd__dlrtp_4 = partial(import_gds, "sky130_fd_sc_hd__dlrtp_4.gds")
sky130_fd_sc_hd__dlxbn_1 = partial(import_gds, "sky130_fd_sc_hd__dlxbn_1.gds")
sky130_fd_sc_hd__dlxbn_2 = partial(import_gds, "sky130_fd_sc_hd__dlxbn_2.gds")
sky130_fd_sc_hd__dlxbp_1 = partial(import_gds, "sky130_fd_sc_hd__dlxbp_1.gds")
sky130_fd_sc_hd__dlxtn_1 = partial(import_gds, "sky130_fd_sc_hd__dlxtn_1.gds")
sky130_fd_sc_hd__dlxtn_2 = partial(import_gds, "sky130_fd_sc_hd__dlxtn_2.gds")
sky130_fd_sc_hd__dlxtn_4 = partial(import_gds, "sky130_fd_sc_hd__dlxtn_4.gds")
sky130_fd_sc_hd__dlxtp_1 = partial(import_gds, "sky130_fd_sc_hd__dlxtp_1.gds")
sky130_fd_sc_hd__dlygate4sd1_1 = partial(
    import_gds, "sky130_fd_sc_hd__dlygate4sd1_1.gds"
)
sky130_fd_sc_hd__dlygate4sd2_1 = partial(
    import_gds, "sky130_fd_sc_hd__dlygate4sd2_1.gds"
)
sky130_fd_sc_hd__dlygate4sd3_1 = partial(
    import_gds, "sky130_fd_sc_hd__dlygate4sd3_1.gds"
)
sky130_fd_sc_hd__dlymetal6s2s_1 = partial(
    import_gds, "sky130_fd_sc_hd__dlymetal6s2s_1.gds"
)
sky130_fd_sc_hd__dlymetal6s4s_1 = partial(
    import_gds, "sky130_fd_sc_hd__dlymetal6s4s_1.gds"
)
sky130_fd_sc_hd__dlymetal6s6s_1 = partial(
    import_gds, "sky130_fd_sc_hd__dlymetal6s6s_1.gds"
)
sky130_fd_sc_hd__ebufn_1 = partial(import_gds, "sky130_fd_sc_hd__ebufn_1.gds")
sky130_fd_sc_hd__ebufn_2 = partial(import_gds, "sky130_fd_sc_hd__ebufn_2.gds")
sky130_fd_sc_hd__ebufn_4 = partial(import_gds, "sky130_fd_sc_hd__ebufn_4.gds")
sky130_fd_sc_hd__ebufn_8 = partial(import_gds, "sky130_fd_sc_hd__ebufn_8.gds")
sky130_fd_sc_hd__edfxbp_1 = partial(import_gds, "sky130_fd_sc_hd__edfxbp_1.gds")
sky130_fd_sc_hd__edfxtp_1 = partial(import_gds, "sky130_fd_sc_hd__edfxtp_1.gds")
sky130_fd_sc_hd__einvn_0 = partial(import_gds, "sky130_fd_sc_hd__einvn_0.gds")
sky130_fd_sc_hd__einvn_1 = partial(import_gds, "sky130_fd_sc_hd__einvn_1.gds")
sky130_fd_sc_hd__einvn_2 = partial(import_gds, "sky130_fd_sc_hd__einvn_2.gds")
sky130_fd_sc_hd__einvn_4 = partial(import_gds, "sky130_fd_sc_hd__einvn_4.gds")
sky130_fd_sc_hd__einvn_8 = partial(import_gds, "sky130_fd_sc_hd__einvn_8.gds")
sky130_fd_sc_hd__einvp_1 = partial(import_gds, "sky130_fd_sc_hd__einvp_1.gds")
sky130_fd_sc_hd__einvp_2 = partial(import_gds, "sky130_fd_sc_hd__einvp_2.gds")
sky130_fd_sc_hd__einvp_4 = partial(import_gds, "sky130_fd_sc_hd__einvp_4.gds")
sky130_fd_sc_hd__einvp_8 = partial(import_gds, "sky130_fd_sc_hd__einvp_8.gds")
sky130_fd_sc_hd__fa_1 = partial(import_gds, "sky130_fd_sc_hd__fa_1.gds")
sky130_fd_sc_hd__fa_2 = partial(import_gds, "sky130_fd_sc_hd__fa_2.gds")
sky130_fd_sc_hd__fa_4 = partial(import_gds, "sky130_fd_sc_hd__fa_4.gds")
sky130_fd_sc_hd__fah_1 = partial(import_gds, "sky130_fd_sc_hd__fah_1.gds")
sky130_fd_sc_hd__fahcin_1 = partial(import_gds, "sky130_fd_sc_hd__fahcin_1.gds")
sky130_fd_sc_hd__fahcon_1 = partial(import_gds, "sky130_fd_sc_hd__fahcon_1.gds")
sky130_fd_sc_hd__fill_1 = partial(import_gds, "sky130_fd_sc_hd__fill_1.gds")
sky130_fd_sc_hd__fill_2 = partial(import_gds, "sky130_fd_sc_hd__fill_2.gds")
sky130_fd_sc_hd__fill_4 = partial(import_gds, "sky130_fd_sc_hd__fill_4.gds")
sky130_fd_sc_hd__fill_8 = partial(import_gds, "sky130_fd_sc_hd__fill_8.gds")
sky130_fd_sc_hd__ha_1 = partial(import_gds, "sky130_fd_sc_hd__ha_1.gds")
sky130_fd_sc_hd__ha_2 = partial(import_gds, "sky130_fd_sc_hd__ha_2.gds")
sky130_fd_sc_hd__ha_4 = partial(import_gds, "sky130_fd_sc_hd__ha_4.gds")
sky130_fd_sc_hd__inv_1 = partial(import_gds, "sky130_fd_sc_hd__inv_1.gds")
sky130_fd_sc_hd__inv_12 = partial(import_gds, "sky130_fd_sc_hd__inv_12.gds")
sky130_fd_sc_hd__inv_16 = partial(import_gds, "sky130_fd_sc_hd__inv_16.gds")
sky130_fd_sc_hd__inv_2 = partial(import_gds, "sky130_fd_sc_hd__inv_2.gds")
sky130_fd_sc_hd__inv_4 = partial(import_gds, "sky130_fd_sc_hd__inv_4.gds")
sky130_fd_sc_hd__inv_6 = partial(import_gds, "sky130_fd_sc_hd__inv_6.gds")
sky130_fd_sc_hd__inv_8 = partial(import_gds, "sky130_fd_sc_hd__inv_8.gds")
sky130_fd_sc_hd__lpflow_bleeder_1 = partial(
    import_gds, "sky130_fd_sc_hd__lpflow_bleeder_1.gds"
)
sky130_fd_sc_hd__lpflow_clkbufkapwr_1 = partial(
    import_gds, "sky130_fd_sc_hd__lpflow_clkbufkapwr_1.gds"
)
sky130_fd_sc_hd__lpflow_clkbufkapwr_16 = partial(
    import_gds, "sky130_fd_sc_hd__lpflow_clkbufkapwr_16.gds"
)
sky130_fd_sc_hd__lpflow_clkbufkapwr_2 = partial(
    import_gds, "sky130_fd_sc_hd__lpflow_clkbufkapwr_2.gds"
)
sky130_fd_sc_hd__lpflow_clkbufkapwr_4 = partial(
    import_gds, "sky130_fd_sc_hd__lpflow_clkbufkapwr_4.gds"
)
sky130_fd_sc_hd__lpflow_clkbufkapwr_8 = partial(
    import_gds, "sky130_fd_sc_hd__lpflow_clkbufkapwr_8.gds"
)
sky130_fd_sc_hd__lpflow_clkinvkapwr_1 = partial(
    import_gds, "sky130_fd_sc_hd__lpflow_clkinvkapwr_1.gds"
)
sky130_fd_sc_hd__lpflow_clkinvkapwr_16 = partial(
    import_gds, "sky130_fd_sc_hd__lpflow_clkinvkapwr_16.gds"
)
sky130_fd_sc_hd__lpflow_clkinvkapwr_2 = partial(
    import_gds, "sky130_fd_sc_hd__lpflow_clkinvkapwr_2.gds"
)
sky130_fd_sc_hd__lpflow_clkinvkapwr_4 = partial(
    import_gds, "sky130_fd_sc_hd__lpflow_clkinvkapwr_4.gds"
)
sky130_fd_sc_hd__lpflow_clkinvkapwr_8 = partial(
    import_gds, "sky130_fd_sc_hd__lpflow_clkinvkapwr_8.gds"
)
sky130_fd_sc_hd__lpflow_decapkapwr_12 = partial(
    import_gds, "sky130_fd_sc_hd__lpflow_decapkapwr_12.gds"
)
sky130_fd_sc_hd__lpflow_decapkapwr_3 = partial(
    import_gds, "sky130_fd_sc_hd__lpflow_decapkapwr_3.gds"
)
sky130_fd_sc_hd__lpflow_decapkapwr_4 = partial(
    import_gds, "sky130_fd_sc_hd__lpflow_decapkapwr_4.gds"
)
sky130_fd_sc_hd__lpflow_decapkapwr_6 = partial(
    import_gds, "sky130_fd_sc_hd__lpflow_decapkapwr_6.gds"
)
sky130_fd_sc_hd__lpflow_decapkapwr_8 = partial(
    import_gds, "sky130_fd_sc_hd__lpflow_decapkapwr_8.gds"
)
sky130_fd_sc_hd__lpflow_inputiso0n_1 = partial(
    import_gds, "sky130_fd_sc_hd__lpflow_inputiso0n_1.gds"
)
sky130_fd_sc_hd__lpflow_inputiso0p_1 = partial(
    import_gds, "sky130_fd_sc_hd__lpflow_inputiso0p_1.gds"
)
sky130_fd_sc_hd__lpflow_inputiso1n_1 = partial(
    import_gds, "sky130_fd_sc_hd__lpflow_inputiso1n_1.gds"
)
sky130_fd_sc_hd__lpflow_inputiso1p_1 = partial(
    import_gds, "sky130_fd_sc_hd__lpflow_inputiso1p_1.gds"
)
sky130_fd_sc_hd__lpflow_inputisolatch_1 = partial(
    import_gds, "sky130_fd_sc_hd__lpflow_inputisolatch_1.gds"
)
sky130_fd_sc_hd__lpflow_isobufsrc_1 = partial(
    import_gds, "sky130_fd_sc_hd__lpflow_isobufsrc_1.gds"
)
sky130_fd_sc_hd__lpflow_isobufsrc_16 = partial(
    import_gds, "sky130_fd_sc_hd__lpflow_isobufsrc_16.gds"
)
sky130_fd_sc_hd__lpflow_isobufsrc_2 = partial(
    import_gds, "sky130_fd_sc_hd__lpflow_isobufsrc_2.gds"
)
sky130_fd_sc_hd__lpflow_isobufsrc_4 = partial(
    import_gds, "sky130_fd_sc_hd__lpflow_isobufsrc_4.gds"
)
sky130_fd_sc_hd__lpflow_isobufsrc_8 = partial(
    import_gds, "sky130_fd_sc_hd__lpflow_isobufsrc_8.gds"
)
sky130_fd_sc_hd__lpflow_isobufsrckapwr_16 = partial(
    import_gds, "sky130_fd_sc_hd__lpflow_isobufsrckapwr_16.gds"
)
sky130_fd_sc_hd__lpflow_lsbuf_lh_hl_isowell_tap_1 = partial(
    import_gds, "sky130_fd_sc_hd__lpflow_lsbuf_lh_hl_isowell_tap_1.gds"
)
sky130_fd_sc_hd__lpflow_lsbuf_lh_hl_isowell_tap_2 = partial(
    import_gds, "sky130_fd_sc_hd__lpflow_lsbuf_lh_hl_isowell_tap_2.gds"
)
sky130_fd_sc_hd__lpflow_lsbuf_lh_hl_isowell_tap_4 = partial(
    import_gds, "sky130_fd_sc_hd__lpflow_lsbuf_lh_hl_isowell_tap_4.gds"
)
sky130_fd_sc_hd__lpflow_lsbuf_lh_isowell_4 = partial(
    import_gds, "sky130_fd_sc_hd__lpflow_lsbuf_lh_isowell_4.gds"
)
sky130_fd_sc_hd__lpflow_lsbuf_lh_isowell_tap_1 = partial(
    import_gds, "sky130_fd_sc_hd__lpflow_lsbuf_lh_isowell_tap_1.gds"
)
sky130_fd_sc_hd__lpflow_lsbuf_lh_isowell_tap_2 = partial(
    import_gds, "sky130_fd_sc_hd__lpflow_lsbuf_lh_isowell_tap_2.gds"
)
sky130_fd_sc_hd__lpflow_lsbuf_lh_isowell_tap_4 = partial(
    import_gds, "sky130_fd_sc_hd__lpflow_lsbuf_lh_isowell_tap_4.gds"
)
sky130_fd_sc_hd__macro_sparecell = partial(
    import_gds, "sky130_fd_sc_hd__macro_sparecell.gds"
)
sky130_fd_sc_hd__maj3_1 = partial(import_gds, "sky130_fd_sc_hd__maj3_1.gds")
sky130_fd_sc_hd__maj3_2 = partial(import_gds, "sky130_fd_sc_hd__maj3_2.gds")
sky130_fd_sc_hd__maj3_4 = partial(import_gds, "sky130_fd_sc_hd__maj3_4.gds")
sky130_fd_sc_hd__mux2_1 = partial(import_gds, "sky130_fd_sc_hd__mux2_1.gds")
sky130_fd_sc_hd__mux2_2 = partial(import_gds, "sky130_fd_sc_hd__mux2_2.gds")
sky130_fd_sc_hd__mux2_4 = partial(import_gds, "sky130_fd_sc_hd__mux2_4.gds")
sky130_fd_sc_hd__mux2_8 = partial(import_gds, "sky130_fd_sc_hd__mux2_8.gds")
sky130_fd_sc_hd__mux2i_1 = partial(import_gds, "sky130_fd_sc_hd__mux2i_1.gds")
sky130_fd_sc_hd__mux2i_2 = partial(import_gds, "sky130_fd_sc_hd__mux2i_2.gds")
sky130_fd_sc_hd__mux2i_4 = partial(import_gds, "sky130_fd_sc_hd__mux2i_4.gds")
sky130_fd_sc_hd__mux4_1 = partial(import_gds, "sky130_fd_sc_hd__mux4_1.gds")
sky130_fd_sc_hd__mux4_2 = partial(import_gds, "sky130_fd_sc_hd__mux4_2.gds")
sky130_fd_sc_hd__mux4_4 = partial(import_gds, "sky130_fd_sc_hd__mux4_4.gds")
sky130_fd_sc_hd__nand2_1 = partial(import_gds, "sky130_fd_sc_hd__nand2_1.gds")
sky130_fd_sc_hd__nand2_2 = partial(import_gds, "sky130_fd_sc_hd__nand2_2.gds")
sky130_fd_sc_hd__nand2_4 = partial(import_gds, "sky130_fd_sc_hd__nand2_4.gds")
sky130_fd_sc_hd__nand2_8 = partial(import_gds, "sky130_fd_sc_hd__nand2_8.gds")
sky130_fd_sc_hd__nand2b_1 = partial(import_gds, "sky130_fd_sc_hd__nand2b_1.gds")
sky130_fd_sc_hd__nand2b_2 = partial(import_gds, "sky130_fd_sc_hd__nand2b_2.gds")
sky130_fd_sc_hd__nand2b_4 = partial(import_gds, "sky130_fd_sc_hd__nand2b_4.gds")
sky130_fd_sc_hd__nand3_1 = partial(import_gds, "sky130_fd_sc_hd__nand3_1.gds")
sky130_fd_sc_hd__nand3_2 = partial(import_gds, "sky130_fd_sc_hd__nand3_2.gds")
sky130_fd_sc_hd__nand3_4 = partial(import_gds, "sky130_fd_sc_hd__nand3_4.gds")
sky130_fd_sc_hd__nand3b_1 = partial(import_gds, "sky130_fd_sc_hd__nand3b_1.gds")
sky130_fd_sc_hd__nand3b_2 = partial(import_gds, "sky130_fd_sc_hd__nand3b_2.gds")
sky130_fd_sc_hd__nand3b_4 = partial(import_gds, "sky130_fd_sc_hd__nand3b_4.gds")
sky130_fd_sc_hd__nand4_1 = partial(import_gds, "sky130_fd_sc_hd__nand4_1.gds")
sky130_fd_sc_hd__nand4_2 = partial(import_gds, "sky130_fd_sc_hd__nand4_2.gds")
sky130_fd_sc_hd__nand4_4 = partial(import_gds, "sky130_fd_sc_hd__nand4_4.gds")
sky130_fd_sc_hd__nand4b_1 = partial(import_gds, "sky130_fd_sc_hd__nand4b_1.gds")
sky130_fd_sc_hd__nand4b_2 = partial(import_gds, "sky130_fd_sc_hd__nand4b_2.gds")
sky130_fd_sc_hd__nand4b_4 = partial(import_gds, "sky130_fd_sc_hd__nand4b_4.gds")
sky130_fd_sc_hd__nand4bb_1 = partial(import_gds, "sky130_fd_sc_hd__nand4bb_1.gds")
sky130_fd_sc_hd__nand4bb_2 = partial(import_gds, "sky130_fd_sc_hd__nand4bb_2.gds")
sky130_fd_sc_hd__nand4bb_4 = partial(import_gds, "sky130_fd_sc_hd__nand4bb_4.gds")
sky130_fd_sc_hd__nor2_1 = partial(import_gds, "sky130_fd_sc_hd__nor2_1.gds")
sky130_fd_sc_hd__nor2_2 = partial(import_gds, "sky130_fd_sc_hd__nor2_2.gds")
sky130_fd_sc_hd__nor2_4 = partial(import_gds, "sky130_fd_sc_hd__nor2_4.gds")
sky130_fd_sc_hd__nor2_8 = partial(import_gds, "sky130_fd_sc_hd__nor2_8.gds")
sky130_fd_sc_hd__nor2b_1 = partial(import_gds, "sky130_fd_sc_hd__nor2b_1.gds")
sky130_fd_sc_hd__nor2b_2 = partial(import_gds, "sky130_fd_sc_hd__nor2b_2.gds")
sky130_fd_sc_hd__nor2b_4 = partial(import_gds, "sky130_fd_sc_hd__nor2b_4.gds")
sky130_fd_sc_hd__nor3_1 = partial(import_gds, "sky130_fd_sc_hd__nor3_1.gds")
sky130_fd_sc_hd__nor3_2 = partial(import_gds, "sky130_fd_sc_hd__nor3_2.gds")
sky130_fd_sc_hd__nor3_4 = partial(import_gds, "sky130_fd_sc_hd__nor3_4.gds")
sky130_fd_sc_hd__nor3b_1 = partial(import_gds, "sky130_fd_sc_hd__nor3b_1.gds")
sky130_fd_sc_hd__nor3b_2 = partial(import_gds, "sky130_fd_sc_hd__nor3b_2.gds")
sky130_fd_sc_hd__nor3b_4 = partial(import_gds, "sky130_fd_sc_hd__nor3b_4.gds")
sky130_fd_sc_hd__nor4_1 = partial(import_gds, "sky130_fd_sc_hd__nor4_1.gds")
sky130_fd_sc_hd__nor4_2 = partial(import_gds, "sky130_fd_sc_hd__nor4_2.gds")
sky130_fd_sc_hd__nor4_4 = partial(import_gds, "sky130_fd_sc_hd__nor4_4.gds")
sky130_fd_sc_hd__nor4b_1 = partial(import_gds, "sky130_fd_sc_hd__nor4b_1.gds")
sky130_fd_sc_hd__nor4b_2 = partial(import_gds, "sky130_fd_sc_hd__nor4b_2.gds")
sky130_fd_sc_hd__nor4b_4 = partial(import_gds, "sky130_fd_sc_hd__nor4b_4.gds")
sky130_fd_sc_hd__nor4bb_1 = partial(import_gds, "sky130_fd_sc_hd__nor4bb_1.gds")
sky130_fd_sc_hd__nor4bb_2 = partial(import_gds, "sky130_fd_sc_hd__nor4bb_2.gds")
sky130_fd_sc_hd__nor4bb_4 = partial(import_gds, "sky130_fd_sc_hd__nor4bb_4.gds")
sky130_fd_sc_hd__o2111a_1 = partial(import_gds, "sky130_fd_sc_hd__o2111a_1.gds")
sky130_fd_sc_hd__o2111a_2 = partial(import_gds, "sky130_fd_sc_hd__o2111a_2.gds")
sky130_fd_sc_hd__o2111a_4 = partial(import_gds, "sky130_fd_sc_hd__o2111a_4.gds")
sky130_fd_sc_hd__o2111ai_1 = partial(import_gds, "sky130_fd_sc_hd__o2111ai_1.gds")
sky130_fd_sc_hd__o2111ai_2 = partial(import_gds, "sky130_fd_sc_hd__o2111ai_2.gds")
sky130_fd_sc_hd__o2111ai_4 = partial(import_gds, "sky130_fd_sc_hd__o2111ai_4.gds")
sky130_fd_sc_hd__o211a_1 = partial(import_gds, "sky130_fd_sc_hd__o211a_1.gds")
sky130_fd_sc_hd__o211a_2 = partial(import_gds, "sky130_fd_sc_hd__o211a_2.gds")
sky130_fd_sc_hd__o211a_4 = partial(import_gds, "sky130_fd_sc_hd__o211a_4.gds")
sky130_fd_sc_hd__o211ai_1 = partial(import_gds, "sky130_fd_sc_hd__o211ai_1.gds")
sky130_fd_sc_hd__o211ai_2 = partial(import_gds, "sky130_fd_sc_hd__o211ai_2.gds")
sky130_fd_sc_hd__o211ai_4 = partial(import_gds, "sky130_fd_sc_hd__o211ai_4.gds")
sky130_fd_sc_hd__o21a_1 = partial(import_gds, "sky130_fd_sc_hd__o21a_1.gds")
sky130_fd_sc_hd__o21a_2 = partial(import_gds, "sky130_fd_sc_hd__o21a_2.gds")
sky130_fd_sc_hd__o21a_4 = partial(import_gds, "sky130_fd_sc_hd__o21a_4.gds")
sky130_fd_sc_hd__o21ai_0 = partial(import_gds, "sky130_fd_sc_hd__o21ai_0.gds")
sky130_fd_sc_hd__o21ai_1 = partial(import_gds, "sky130_fd_sc_hd__o21ai_1.gds")
sky130_fd_sc_hd__o21ai_2 = partial(import_gds, "sky130_fd_sc_hd__o21ai_2.gds")
sky130_fd_sc_hd__o21ai_4 = partial(import_gds, "sky130_fd_sc_hd__o21ai_4.gds")
sky130_fd_sc_hd__o21ba_1 = partial(import_gds, "sky130_fd_sc_hd__o21ba_1.gds")
sky130_fd_sc_hd__o21ba_2 = partial(import_gds, "sky130_fd_sc_hd__o21ba_2.gds")
sky130_fd_sc_hd__o21ba_4 = partial(import_gds, "sky130_fd_sc_hd__o21ba_4.gds")
sky130_fd_sc_hd__o21bai_1 = partial(import_gds, "sky130_fd_sc_hd__o21bai_1.gds")
sky130_fd_sc_hd__o21bai_2 = partial(import_gds, "sky130_fd_sc_hd__o21bai_2.gds")
sky130_fd_sc_hd__o21bai_4 = partial(import_gds, "sky130_fd_sc_hd__o21bai_4.gds")
sky130_fd_sc_hd__o221a_1 = partial(import_gds, "sky130_fd_sc_hd__o221a_1.gds")
sky130_fd_sc_hd__o221a_2 = partial(import_gds, "sky130_fd_sc_hd__o221a_2.gds")
sky130_fd_sc_hd__o221a_4 = partial(import_gds, "sky130_fd_sc_hd__o221a_4.gds")
sky130_fd_sc_hd__o221ai_1 = partial(import_gds, "sky130_fd_sc_hd__o221ai_1.gds")
sky130_fd_sc_hd__o221ai_2 = partial(import_gds, "sky130_fd_sc_hd__o221ai_2.gds")
sky130_fd_sc_hd__o221ai_4 = partial(import_gds, "sky130_fd_sc_hd__o221ai_4.gds")
sky130_fd_sc_hd__o22a_1 = partial(import_gds, "sky130_fd_sc_hd__o22a_1.gds")
sky130_fd_sc_hd__o22a_2 = partial(import_gds, "sky130_fd_sc_hd__o22a_2.gds")
sky130_fd_sc_hd__o22a_4 = partial(import_gds, "sky130_fd_sc_hd__o22a_4.gds")
sky130_fd_sc_hd__o22ai_1 = partial(import_gds, "sky130_fd_sc_hd__o22ai_1.gds")
sky130_fd_sc_hd__o22ai_2 = partial(import_gds, "sky130_fd_sc_hd__o22ai_2.gds")
sky130_fd_sc_hd__o22ai_4 = partial(import_gds, "sky130_fd_sc_hd__o22ai_4.gds")
sky130_fd_sc_hd__o2bb2a_1 = partial(import_gds, "sky130_fd_sc_hd__o2bb2a_1.gds")
sky130_fd_sc_hd__o2bb2a_2 = partial(import_gds, "sky130_fd_sc_hd__o2bb2a_2.gds")
sky130_fd_sc_hd__o2bb2a_4 = partial(import_gds, "sky130_fd_sc_hd__o2bb2a_4.gds")
sky130_fd_sc_hd__o2bb2ai_1 = partial(import_gds, "sky130_fd_sc_hd__o2bb2ai_1.gds")
sky130_fd_sc_hd__o2bb2ai_2 = partial(import_gds, "sky130_fd_sc_hd__o2bb2ai_2.gds")
sky130_fd_sc_hd__o2bb2ai_4 = partial(import_gds, "sky130_fd_sc_hd__o2bb2ai_4.gds")
sky130_fd_sc_hd__o311a_1 = partial(import_gds, "sky130_fd_sc_hd__o311a_1.gds")
sky130_fd_sc_hd__o311a_2 = partial(import_gds, "sky130_fd_sc_hd__o311a_2.gds")
sky130_fd_sc_hd__o311a_4 = partial(import_gds, "sky130_fd_sc_hd__o311a_4.gds")
sky130_fd_sc_hd__o311ai_0 = partial(import_gds, "sky130_fd_sc_hd__o311ai_0.gds")
sky130_fd_sc_hd__o311ai_1 = partial(import_gds, "sky130_fd_sc_hd__o311ai_1.gds")
sky130_fd_sc_hd__o311ai_2 = partial(import_gds, "sky130_fd_sc_hd__o311ai_2.gds")
sky130_fd_sc_hd__o311ai_4 = partial(import_gds, "sky130_fd_sc_hd__o311ai_4.gds")
sky130_fd_sc_hd__o31a_1 = partial(import_gds, "sky130_fd_sc_hd__o31a_1.gds")
sky130_fd_sc_hd__o31a_2 = partial(import_gds, "sky130_fd_sc_hd__o31a_2.gds")
sky130_fd_sc_hd__o31a_4 = partial(import_gds, "sky130_fd_sc_hd__o31a_4.gds")
sky130_fd_sc_hd__o31ai_1 = partial(import_gds, "sky130_fd_sc_hd__o31ai_1.gds")
sky130_fd_sc_hd__o31ai_2 = partial(import_gds, "sky130_fd_sc_hd__o31ai_2.gds")
sky130_fd_sc_hd__o31ai_4 = partial(import_gds, "sky130_fd_sc_hd__o31ai_4.gds")
sky130_fd_sc_hd__o32a_1 = partial(import_gds, "sky130_fd_sc_hd__o32a_1.gds")
sky130_fd_sc_hd__o32a_2 = partial(import_gds, "sky130_fd_sc_hd__o32a_2.gds")
sky130_fd_sc_hd__o32a_4 = partial(import_gds, "sky130_fd_sc_hd__o32a_4.gds")
sky130_fd_sc_hd__o32ai_1 = partial(import_gds, "sky130_fd_sc_hd__o32ai_1.gds")
sky130_fd_sc_hd__o32ai_2 = partial(import_gds, "sky130_fd_sc_hd__o32ai_2.gds")
sky130_fd_sc_hd__o32ai_4 = partial(import_gds, "sky130_fd_sc_hd__o32ai_4.gds")
sky130_fd_sc_hd__o41a_1 = partial(import_gds, "sky130_fd_sc_hd__o41a_1.gds")
sky130_fd_sc_hd__o41a_2 = partial(import_gds, "sky130_fd_sc_hd__o41a_2.gds")
sky130_fd_sc_hd__o41a_4 = partial(import_gds, "sky130_fd_sc_hd__o41a_4.gds")
sky130_fd_sc_hd__o41ai_1 = partial(import_gds, "sky130_fd_sc_hd__o41ai_1.gds")
sky130_fd_sc_hd__o41ai_2 = partial(import_gds, "sky130_fd_sc_hd__o41ai_2.gds")
sky130_fd_sc_hd__o41ai_4 = partial(import_gds, "sky130_fd_sc_hd__o41ai_4.gds")
sky130_fd_sc_hd__or2_0 = partial(import_gds, "sky130_fd_sc_hd__or2_0.gds")
sky130_fd_sc_hd__or2_1 = partial(import_gds, "sky130_fd_sc_hd__or2_1.gds")
sky130_fd_sc_hd__or2_2 = partial(import_gds, "sky130_fd_sc_hd__or2_2.gds")
sky130_fd_sc_hd__or2_4 = partial(import_gds, "sky130_fd_sc_hd__or2_4.gds")
sky130_fd_sc_hd__or2b_1 = partial(import_gds, "sky130_fd_sc_hd__or2b_1.gds")
sky130_fd_sc_hd__or2b_2 = partial(import_gds, "sky130_fd_sc_hd__or2b_2.gds")
sky130_fd_sc_hd__or2b_4 = partial(import_gds, "sky130_fd_sc_hd__or2b_4.gds")
sky130_fd_sc_hd__or3_1 = partial(import_gds, "sky130_fd_sc_hd__or3_1.gds")
sky130_fd_sc_hd__or3_2 = partial(import_gds, "sky130_fd_sc_hd__or3_2.gds")
sky130_fd_sc_hd__or3_4 = partial(import_gds, "sky130_fd_sc_hd__or3_4.gds")
sky130_fd_sc_hd__or3b_1 = partial(import_gds, "sky130_fd_sc_hd__or3b_1.gds")
sky130_fd_sc_hd__or3b_2 = partial(import_gds, "sky130_fd_sc_hd__or3b_2.gds")
sky130_fd_sc_hd__or3b_4 = partial(import_gds, "sky130_fd_sc_hd__or3b_4.gds")
sky130_fd_sc_hd__or4_1 = partial(import_gds, "sky130_fd_sc_hd__or4_1.gds")
sky130_fd_sc_hd__or4_2 = partial(import_gds, "sky130_fd_sc_hd__or4_2.gds")
sky130_fd_sc_hd__or4_4 = partial(import_gds, "sky130_fd_sc_hd__or4_4.gds")
sky130_fd_sc_hd__or4b_1 = partial(import_gds, "sky130_fd_sc_hd__or4b_1.gds")
sky130_fd_sc_hd__or4b_2 = partial(import_gds, "sky130_fd_sc_hd__or4b_2.gds")
sky130_fd_sc_hd__or4b_4 = partial(import_gds, "sky130_fd_sc_hd__or4b_4.gds")
sky130_fd_sc_hd__or4bb_1 = partial(import_gds, "sky130_fd_sc_hd__or4bb_1.gds")
sky130_fd_sc_hd__or4bb_2 = partial(import_gds, "sky130_fd_sc_hd__or4bb_2.gds")
sky130_fd_sc_hd__or4bb_4 = partial(import_gds, "sky130_fd_sc_hd__or4bb_4.gds")
sky130_fd_sc_hd__probe_p_8 = partial(import_gds, "sky130_fd_sc_hd__probe_p_8.gds")
sky130_fd_sc_hd__probec_p_8 = partial(import_gds, "sky130_fd_sc_hd__probec_p_8.gds")
sky130_fd_sc_hd__sdfbbn_1 = partial(import_gds, "sky130_fd_sc_hd__sdfbbn_1.gds")
sky130_fd_sc_hd__sdfbbn_2 = partial(import_gds, "sky130_fd_sc_hd__sdfbbn_2.gds")
sky130_fd_sc_hd__sdfbbp_1 = partial(import_gds, "sky130_fd_sc_hd__sdfbbp_1.gds")
sky130_fd_sc_hd__sdfrbp_1 = partial(import_gds, "sky130_fd_sc_hd__sdfrbp_1.gds")
sky130_fd_sc_hd__sdfrbp_2 = partial(import_gds, "sky130_fd_sc_hd__sdfrbp_2.gds")
sky130_fd_sc_hd__sdfrtn_1 = partial(import_gds, "sky130_fd_sc_hd__sdfrtn_1.gds")
sky130_fd_sc_hd__sdfrtp_1 = partial(import_gds, "sky130_fd_sc_hd__sdfrtp_1.gds")
sky130_fd_sc_hd__sdfrtp_2 = partial(import_gds, "sky130_fd_sc_hd__sdfrtp_2.gds")
sky130_fd_sc_hd__sdfrtp_4 = partial(import_gds, "sky130_fd_sc_hd__sdfrtp_4.gds")
sky130_fd_sc_hd__sdfsbp_1 = partial(import_gds, "sky130_fd_sc_hd__sdfsbp_1.gds")
sky130_fd_sc_hd__sdfsbp_2 = partial(import_gds, "sky130_fd_sc_hd__sdfsbp_2.gds")
sky130_fd_sc_hd__sdfstp_1 = partial(import_gds, "sky130_fd_sc_hd__sdfstp_1.gds")
sky130_fd_sc_hd__sdfstp_2 = partial(import_gds, "sky130_fd_sc_hd__sdfstp_2.gds")
sky130_fd_sc_hd__sdfstp_4 = partial(import_gds, "sky130_fd_sc_hd__sdfstp_4.gds")
sky130_fd_sc_hd__sdfxbp_1 = partial(import_gds, "sky130_fd_sc_hd__sdfxbp_1.gds")
sky130_fd_sc_hd__sdfxbp_2 = partial(import_gds, "sky130_fd_sc_hd__sdfxbp_2.gds")
sky130_fd_sc_hd__sdfxtp_1 = partial(import_gds, "sky130_fd_sc_hd__sdfxtp_1.gds")
sky130_fd_sc_hd__sdfxtp_2 = partial(import_gds, "sky130_fd_sc_hd__sdfxtp_2.gds")
sky130_fd_sc_hd__sdfxtp_4 = partial(import_gds, "sky130_fd_sc_hd__sdfxtp_4.gds")
sky130_fd_sc_hd__sdlclkp_1 = partial(import_gds, "sky130_fd_sc_hd__sdlclkp_1.gds")
sky130_fd_sc_hd__sdlclkp_2 = partial(import_gds, "sky130_fd_sc_hd__sdlclkp_2.gds")
sky130_fd_sc_hd__sdlclkp_4 = partial(import_gds, "sky130_fd_sc_hd__sdlclkp_4.gds")
sky130_fd_sc_hd__sedfxbp_1 = partial(import_gds, "sky130_fd_sc_hd__sedfxbp_1.gds")
sky130_fd_sc_hd__sedfxbp_2 = partial(import_gds, "sky130_fd_sc_hd__sedfxbp_2.gds")
sky130_fd_sc_hd__sedfxtp_1 = partial(import_gds, "sky130_fd_sc_hd__sedfxtp_1.gds")
sky130_fd_sc_hd__sedfxtp_2 = partial(import_gds, "sky130_fd_sc_hd__sedfxtp_2.gds")
sky130_fd_sc_hd__sedfxtp_4 = partial(import_gds, "sky130_fd_sc_hd__sedfxtp_4.gds")
sky130_fd_sc_hd__tap_1 = partial(import_gds, "sky130_fd_sc_hd__tap_1.gds")
sky130_fd_sc_hd__tap_2 = partial(import_gds, "sky130_fd_sc_hd__tap_2.gds")
sky130_fd_sc_hd__tapvgnd2_1 = partial(import_gds, "sky130_fd_sc_hd__tapvgnd2_1.gds")
sky130_fd_sc_hd__tapvgnd_1 = partial(import_gds, "sky130_fd_sc_hd__tapvgnd_1.gds")
sky130_fd_sc_hd__tapvpwrvgnd_1 = partial(
    import_gds, "sky130_fd_sc_hd__tapvpwrvgnd_1.gds"
)
sky130_fd_sc_hd__xnor2_1 = partial(import_gds, "sky130_fd_sc_hd__xnor2_1.gds")
sky130_fd_sc_hd__xnor2_2 = partial(import_gds, "sky130_fd_sc_hd__xnor2_2.gds")
sky130_fd_sc_hd__xnor2_4 = partial(import_gds, "sky130_fd_sc_hd__xnor2_4.gds")
sky130_fd_sc_hd__xnor3_1 = partial(import_gds, "sky130_fd_sc_hd__xnor3_1.gds")
sky130_fd_sc_hd__xnor3_2 = partial(import_gds, "sky130_fd_sc_hd__xnor3_2.gds")
sky130_fd_sc_hd__xnor3_4 = partial(import_gds, "sky130_fd_sc_hd__xnor3_4.gds")
sky130_fd_sc_hd__xor2_1 = partial(import_gds, "sky130_fd_sc_hd__xor2_1.gds")
sky130_fd_sc_hd__xor2_2 = partial(import_gds, "sky130_fd_sc_hd__xor2_2.gds")
sky130_fd_sc_hd__xor2_4 = partial(import_gds, "sky130_fd_sc_hd__xor2_4.gds")
sky130_fd_sc_hd__xor3_1 = partial(import_gds, "sky130_fd_sc_hd__xor3_1.gds")
sky130_fd_sc_hd__xor3_2 = partial(import_gds, "sky130_fd_sc_hd__xor3_2.gds")
sky130_fd_sc_hd__xor3_4 = partial(import_gds, "sky130_fd_sc_hd__xor3_4.gds")
sky130_fd_sc_hs__a2111o_1 = partial(import_gds, "sky130_fd_sc_hs__a2111o_1.gds")
sky130_fd_sc_hs__a2111o_2 = partial(import_gds, "sky130_fd_sc_hs__a2111o_2.gds")
sky130_fd_sc_hs__a2111o_4 = partial(import_gds, "sky130_fd_sc_hs__a2111o_4.gds")
sky130_fd_sc_hs__a2111oi_1 = partial(import_gds, "sky130_fd_sc_hs__a2111oi_1.gds")
sky130_fd_sc_hs__a2111oi_2 = partial(import_gds, "sky130_fd_sc_hs__a2111oi_2.gds")
sky130_fd_sc_hs__a2111oi_4 = partial(import_gds, "sky130_fd_sc_hs__a2111oi_4.gds")
sky130_fd_sc_hs__a211o_1 = partial(import_gds, "sky130_fd_sc_hs__a211o_1.gds")
sky130_fd_sc_hs__a211o_2 = partial(import_gds, "sky130_fd_sc_hs__a211o_2.gds")
sky130_fd_sc_hs__a211o_4 = partial(import_gds, "sky130_fd_sc_hs__a211o_4.gds")
sky130_fd_sc_hs__a211oi_1 = partial(import_gds, "sky130_fd_sc_hs__a211oi_1.gds")
sky130_fd_sc_hs__a211oi_2 = partial(import_gds, "sky130_fd_sc_hs__a211oi_2.gds")
sky130_fd_sc_hs__a211oi_4 = partial(import_gds, "sky130_fd_sc_hs__a211oi_4.gds")
sky130_fd_sc_hs__a21bo_1 = partial(import_gds, "sky130_fd_sc_hs__a21bo_1.gds")
sky130_fd_sc_hs__a21bo_2 = partial(import_gds, "sky130_fd_sc_hs__a21bo_2.gds")
sky130_fd_sc_hs__a21bo_4 = partial(import_gds, "sky130_fd_sc_hs__a21bo_4.gds")
sky130_fd_sc_hs__a21boi_1 = partial(import_gds, "sky130_fd_sc_hs__a21boi_1.gds")
sky130_fd_sc_hs__a21boi_2 = partial(import_gds, "sky130_fd_sc_hs__a21boi_2.gds")
sky130_fd_sc_hs__a21boi_4 = partial(import_gds, "sky130_fd_sc_hs__a21boi_4.gds")
sky130_fd_sc_hs__a21o_1 = partial(import_gds, "sky130_fd_sc_hs__a21o_1.gds")
sky130_fd_sc_hs__a21o_2 = partial(import_gds, "sky130_fd_sc_hs__a21o_2.gds")
sky130_fd_sc_hs__a21o_4 = partial(import_gds, "sky130_fd_sc_hs__a21o_4.gds")
sky130_fd_sc_hs__a21oi_1 = partial(import_gds, "sky130_fd_sc_hs__a21oi_1.gds")
sky130_fd_sc_hs__a21oi_2 = partial(import_gds, "sky130_fd_sc_hs__a21oi_2.gds")
sky130_fd_sc_hs__a21oi_4 = partial(import_gds, "sky130_fd_sc_hs__a21oi_4.gds")
sky130_fd_sc_hs__a221o_1 = partial(import_gds, "sky130_fd_sc_hs__a221o_1.gds")
sky130_fd_sc_hs__a221o_2 = partial(import_gds, "sky130_fd_sc_hs__a221o_2.gds")
sky130_fd_sc_hs__a221o_4 = partial(import_gds, "sky130_fd_sc_hs__a221o_4.gds")
sky130_fd_sc_hs__a221oi_1 = partial(import_gds, "sky130_fd_sc_hs__a221oi_1.gds")
sky130_fd_sc_hs__a221oi_2 = partial(import_gds, "sky130_fd_sc_hs__a221oi_2.gds")
sky130_fd_sc_hs__a221oi_4 = partial(import_gds, "sky130_fd_sc_hs__a221oi_4.gds")
sky130_fd_sc_hs__a222o_1 = partial(import_gds, "sky130_fd_sc_hs__a222o_1.gds")
sky130_fd_sc_hs__a222o_2 = partial(import_gds, "sky130_fd_sc_hs__a222o_2.gds")
sky130_fd_sc_hs__a222oi_1 = partial(import_gds, "sky130_fd_sc_hs__a222oi_1.gds")
sky130_fd_sc_hs__a222oi_2 = partial(import_gds, "sky130_fd_sc_hs__a222oi_2.gds")
sky130_fd_sc_hs__a22o_1 = partial(import_gds, "sky130_fd_sc_hs__a22o_1.gds")
sky130_fd_sc_hs__a22o_2 = partial(import_gds, "sky130_fd_sc_hs__a22o_2.gds")
sky130_fd_sc_hs__a22o_4 = partial(import_gds, "sky130_fd_sc_hs__a22o_4.gds")
sky130_fd_sc_hs__a22oi_1 = partial(import_gds, "sky130_fd_sc_hs__a22oi_1.gds")
sky130_fd_sc_hs__a22oi_2 = partial(import_gds, "sky130_fd_sc_hs__a22oi_2.gds")
sky130_fd_sc_hs__a22oi_4 = partial(import_gds, "sky130_fd_sc_hs__a22oi_4.gds")
sky130_fd_sc_hs__a2bb2o_1 = partial(import_gds, "sky130_fd_sc_hs__a2bb2o_1.gds")
sky130_fd_sc_hs__a2bb2o_2 = partial(import_gds, "sky130_fd_sc_hs__a2bb2o_2.gds")
sky130_fd_sc_hs__a2bb2o_4 = partial(import_gds, "sky130_fd_sc_hs__a2bb2o_4.gds")
sky130_fd_sc_hs__a2bb2oi_1 = partial(import_gds, "sky130_fd_sc_hs__a2bb2oi_1.gds")
sky130_fd_sc_hs__a2bb2oi_2 = partial(import_gds, "sky130_fd_sc_hs__a2bb2oi_2.gds")
sky130_fd_sc_hs__a2bb2oi_4 = partial(import_gds, "sky130_fd_sc_hs__a2bb2oi_4.gds")
sky130_fd_sc_hs__a311o_1 = partial(import_gds, "sky130_fd_sc_hs__a311o_1.gds")
sky130_fd_sc_hs__a311o_2 = partial(import_gds, "sky130_fd_sc_hs__a311o_2.gds")
sky130_fd_sc_hs__a311o_4 = partial(import_gds, "sky130_fd_sc_hs__a311o_4.gds")
sky130_fd_sc_hs__a311oi_1 = partial(import_gds, "sky130_fd_sc_hs__a311oi_1.gds")
sky130_fd_sc_hs__a311oi_2 = partial(import_gds, "sky130_fd_sc_hs__a311oi_2.gds")
sky130_fd_sc_hs__a311oi_4 = partial(import_gds, "sky130_fd_sc_hs__a311oi_4.gds")
sky130_fd_sc_hs__a31o_1 = partial(import_gds, "sky130_fd_sc_hs__a31o_1.gds")
sky130_fd_sc_hs__a31o_2 = partial(import_gds, "sky130_fd_sc_hs__a31o_2.gds")
sky130_fd_sc_hs__a31o_4 = partial(import_gds, "sky130_fd_sc_hs__a31o_4.gds")
sky130_fd_sc_hs__a31oi_1 = partial(import_gds, "sky130_fd_sc_hs__a31oi_1.gds")
sky130_fd_sc_hs__a31oi_2 = partial(import_gds, "sky130_fd_sc_hs__a31oi_2.gds")
sky130_fd_sc_hs__a31oi_4 = partial(import_gds, "sky130_fd_sc_hs__a31oi_4.gds")
sky130_fd_sc_hs__a32o_1 = partial(import_gds, "sky130_fd_sc_hs__a32o_1.gds")
sky130_fd_sc_hs__a32o_2 = partial(import_gds, "sky130_fd_sc_hs__a32o_2.gds")
sky130_fd_sc_hs__a32o_4 = partial(import_gds, "sky130_fd_sc_hs__a32o_4.gds")
sky130_fd_sc_hs__a32oi_1 = partial(import_gds, "sky130_fd_sc_hs__a32oi_1.gds")
sky130_fd_sc_hs__a32oi_2 = partial(import_gds, "sky130_fd_sc_hs__a32oi_2.gds")
sky130_fd_sc_hs__a32oi_4 = partial(import_gds, "sky130_fd_sc_hs__a32oi_4.gds")
sky130_fd_sc_hs__a41o_1 = partial(import_gds, "sky130_fd_sc_hs__a41o_1.gds")
sky130_fd_sc_hs__a41o_2 = partial(import_gds, "sky130_fd_sc_hs__a41o_2.gds")
sky130_fd_sc_hs__a41o_4 = partial(import_gds, "sky130_fd_sc_hs__a41o_4.gds")
sky130_fd_sc_hs__a41oi_1 = partial(import_gds, "sky130_fd_sc_hs__a41oi_1.gds")
sky130_fd_sc_hs__a41oi_2 = partial(import_gds, "sky130_fd_sc_hs__a41oi_2.gds")
sky130_fd_sc_hs__a41oi_4 = partial(import_gds, "sky130_fd_sc_hs__a41oi_4.gds")
sky130_fd_sc_hs__and2_1 = partial(import_gds, "sky130_fd_sc_hs__and2_1.gds")
sky130_fd_sc_hs__and2_2 = partial(import_gds, "sky130_fd_sc_hs__and2_2.gds")
sky130_fd_sc_hs__and2_4 = partial(import_gds, "sky130_fd_sc_hs__and2_4.gds")
sky130_fd_sc_hs__and2b_1 = partial(import_gds, "sky130_fd_sc_hs__and2b_1.gds")
sky130_fd_sc_hs__and2b_2 = partial(import_gds, "sky130_fd_sc_hs__and2b_2.gds")
sky130_fd_sc_hs__and2b_4 = partial(import_gds, "sky130_fd_sc_hs__and2b_4.gds")
sky130_fd_sc_hs__and3_1 = partial(import_gds, "sky130_fd_sc_hs__and3_1.gds")
sky130_fd_sc_hs__and3_2 = partial(import_gds, "sky130_fd_sc_hs__and3_2.gds")
sky130_fd_sc_hs__and3_4 = partial(import_gds, "sky130_fd_sc_hs__and3_4.gds")
sky130_fd_sc_hs__and3b_1 = partial(import_gds, "sky130_fd_sc_hs__and3b_1.gds")
sky130_fd_sc_hs__and3b_2 = partial(import_gds, "sky130_fd_sc_hs__and3b_2.gds")
sky130_fd_sc_hs__and3b_4 = partial(import_gds, "sky130_fd_sc_hs__and3b_4.gds")
sky130_fd_sc_hs__and4_1 = partial(import_gds, "sky130_fd_sc_hs__and4_1.gds")
sky130_fd_sc_hs__and4_2 = partial(import_gds, "sky130_fd_sc_hs__and4_2.gds")
sky130_fd_sc_hs__and4_4 = partial(import_gds, "sky130_fd_sc_hs__and4_4.gds")
sky130_fd_sc_hs__and4b_1 = partial(import_gds, "sky130_fd_sc_hs__and4b_1.gds")
sky130_fd_sc_hs__and4b_2 = partial(import_gds, "sky130_fd_sc_hs__and4b_2.gds")
sky130_fd_sc_hs__and4b_4 = partial(import_gds, "sky130_fd_sc_hs__and4b_4.gds")
sky130_fd_sc_hs__and4bb_1 = partial(import_gds, "sky130_fd_sc_hs__and4bb_1.gds")
sky130_fd_sc_hs__and4bb_2 = partial(import_gds, "sky130_fd_sc_hs__and4bb_2.gds")
sky130_fd_sc_hs__and4bb_4 = partial(import_gds, "sky130_fd_sc_hs__and4bb_4.gds")
sky130_fd_sc_hs__buf_1 = partial(import_gds, "sky130_fd_sc_hs__buf_1.gds")
sky130_fd_sc_hs__buf_16 = partial(import_gds, "sky130_fd_sc_hs__buf_16.gds")
sky130_fd_sc_hs__buf_2 = partial(import_gds, "sky130_fd_sc_hs__buf_2.gds")
sky130_fd_sc_hs__buf_4 = partial(import_gds, "sky130_fd_sc_hs__buf_4.gds")
sky130_fd_sc_hs__buf_8 = partial(import_gds, "sky130_fd_sc_hs__buf_8.gds")
sky130_fd_sc_hs__bufbuf_16 = partial(import_gds, "sky130_fd_sc_hs__bufbuf_16.gds")
sky130_fd_sc_hs__bufbuf_8 = partial(import_gds, "sky130_fd_sc_hs__bufbuf_8.gds")
sky130_fd_sc_hs__bufinv_16 = partial(import_gds, "sky130_fd_sc_hs__bufinv_16.gds")
sky130_fd_sc_hs__bufinv_8 = partial(import_gds, "sky130_fd_sc_hs__bufinv_8.gds")
sky130_fd_sc_hs__clkbuf_1 = partial(import_gds, "sky130_fd_sc_hs__clkbuf_1.gds")
sky130_fd_sc_hs__clkbuf_16 = partial(import_gds, "sky130_fd_sc_hs__clkbuf_16.gds")
sky130_fd_sc_hs__clkbuf_2 = partial(import_gds, "sky130_fd_sc_hs__clkbuf_2.gds")
sky130_fd_sc_hs__clkbuf_4 = partial(import_gds, "sky130_fd_sc_hs__clkbuf_4.gds")
sky130_fd_sc_hs__clkbuf_8 = partial(import_gds, "sky130_fd_sc_hs__clkbuf_8.gds")
sky130_fd_sc_hs__clkdlyinv3sd1_1 = partial(
    import_gds, "sky130_fd_sc_hs__clkdlyinv3sd1_1.gds"
)
sky130_fd_sc_hs__clkdlyinv3sd2_1 = partial(
    import_gds, "sky130_fd_sc_hs__clkdlyinv3sd2_1.gds"
)
sky130_fd_sc_hs__clkdlyinv3sd3_1 = partial(
    import_gds, "sky130_fd_sc_hs__clkdlyinv3sd3_1.gds"
)
sky130_fd_sc_hs__clkdlyinv5sd1_1 = partial(
    import_gds, "sky130_fd_sc_hs__clkdlyinv5sd1_1.gds"
)
sky130_fd_sc_hs__clkdlyinv5sd2_1 = partial(
    import_gds, "sky130_fd_sc_hs__clkdlyinv5sd2_1.gds"
)
sky130_fd_sc_hs__clkdlyinv5sd3_1 = partial(
    import_gds, "sky130_fd_sc_hs__clkdlyinv5sd3_1.gds"
)
sky130_fd_sc_hs__clkinv_1 = partial(import_gds, "sky130_fd_sc_hs__clkinv_1.gds")
sky130_fd_sc_hs__clkinv_16 = partial(import_gds, "sky130_fd_sc_hs__clkinv_16.gds")
sky130_fd_sc_hs__clkinv_2 = partial(import_gds, "sky130_fd_sc_hs__clkinv_2.gds")
sky130_fd_sc_hs__clkinv_4 = partial(import_gds, "sky130_fd_sc_hs__clkinv_4.gds")
sky130_fd_sc_hs__clkinv_8 = partial(import_gds, "sky130_fd_sc_hs__clkinv_8.gds")
sky130_fd_sc_hs__conb_1 = partial(import_gds, "sky130_fd_sc_hs__conb_1.gds")
sky130_fd_sc_hs__decap_4 = partial(import_gds, "sky130_fd_sc_hs__decap_4.gds")
sky130_fd_sc_hs__decap_8 = partial(import_gds, "sky130_fd_sc_hs__decap_8.gds")
sky130_fd_sc_hs__dfbbn_1 = partial(import_gds, "sky130_fd_sc_hs__dfbbn_1.gds")
sky130_fd_sc_hs__dfbbn_2 = partial(import_gds, "sky130_fd_sc_hs__dfbbn_2.gds")
sky130_fd_sc_hs__dfbbp_1 = partial(import_gds, "sky130_fd_sc_hs__dfbbp_1.gds")
sky130_fd_sc_hs__dfrbp_1 = partial(import_gds, "sky130_fd_sc_hs__dfrbp_1.gds")
sky130_fd_sc_hs__dfrbp_2 = partial(import_gds, "sky130_fd_sc_hs__dfrbp_2.gds")
sky130_fd_sc_hs__dfrtn_1 = partial(import_gds, "sky130_fd_sc_hs__dfrtn_1.gds")
sky130_fd_sc_hs__dfrtp_1 = partial(import_gds, "sky130_fd_sc_hs__dfrtp_1.gds")
sky130_fd_sc_hs__dfrtp_2 = partial(import_gds, "sky130_fd_sc_hs__dfrtp_2.gds")
sky130_fd_sc_hs__dfrtp_4 = partial(import_gds, "sky130_fd_sc_hs__dfrtp_4.gds")
sky130_fd_sc_hs__dfsbp_1 = partial(import_gds, "sky130_fd_sc_hs__dfsbp_1.gds")
sky130_fd_sc_hs__dfsbp_2 = partial(import_gds, "sky130_fd_sc_hs__dfsbp_2.gds")
sky130_fd_sc_hs__dfstp_1 = partial(import_gds, "sky130_fd_sc_hs__dfstp_1.gds")
sky130_fd_sc_hs__dfstp_2 = partial(import_gds, "sky130_fd_sc_hs__dfstp_2.gds")
sky130_fd_sc_hs__dfstp_4 = partial(import_gds, "sky130_fd_sc_hs__dfstp_4.gds")
sky130_fd_sc_hs__dfxbp_1 = partial(import_gds, "sky130_fd_sc_hs__dfxbp_1.gds")
sky130_fd_sc_hs__dfxbp_2 = partial(import_gds, "sky130_fd_sc_hs__dfxbp_2.gds")
sky130_fd_sc_hs__dfxtp_1 = partial(import_gds, "sky130_fd_sc_hs__dfxtp_1.gds")
sky130_fd_sc_hs__dfxtp_2 = partial(import_gds, "sky130_fd_sc_hs__dfxtp_2.gds")
sky130_fd_sc_hs__dfxtp_4 = partial(import_gds, "sky130_fd_sc_hs__dfxtp_4.gds")
sky130_fd_sc_hs__diode_2 = partial(import_gds, "sky130_fd_sc_hs__diode_2.gds")
sky130_fd_sc_hs__dlclkp_1 = partial(import_gds, "sky130_fd_sc_hs__dlclkp_1.gds")
sky130_fd_sc_hs__dlclkp_2 = partial(import_gds, "sky130_fd_sc_hs__dlclkp_2.gds")
sky130_fd_sc_hs__dlclkp_4 = partial(import_gds, "sky130_fd_sc_hs__dlclkp_4.gds")
sky130_fd_sc_hs__dlrbn_1 = partial(import_gds, "sky130_fd_sc_hs__dlrbn_1.gds")
sky130_fd_sc_hs__dlrbn_2 = partial(import_gds, "sky130_fd_sc_hs__dlrbn_2.gds")
sky130_fd_sc_hs__dlrbp_1 = partial(import_gds, "sky130_fd_sc_hs__dlrbp_1.gds")
sky130_fd_sc_hs__dlrbp_2 = partial(import_gds, "sky130_fd_sc_hs__dlrbp_2.gds")
sky130_fd_sc_hs__dlrtn_1 = partial(import_gds, "sky130_fd_sc_hs__dlrtn_1.gds")
sky130_fd_sc_hs__dlrtn_2 = partial(import_gds, "sky130_fd_sc_hs__dlrtn_2.gds")
sky130_fd_sc_hs__dlrtn_4 = partial(import_gds, "sky130_fd_sc_hs__dlrtn_4.gds")
sky130_fd_sc_hs__dlrtp_1 = partial(import_gds, "sky130_fd_sc_hs__dlrtp_1.gds")
sky130_fd_sc_hs__dlrtp_2 = partial(import_gds, "sky130_fd_sc_hs__dlrtp_2.gds")
sky130_fd_sc_hs__dlrtp_4 = partial(import_gds, "sky130_fd_sc_hs__dlrtp_4.gds")
sky130_fd_sc_hs__dlxbn_1 = partial(import_gds, "sky130_fd_sc_hs__dlxbn_1.gds")
sky130_fd_sc_hs__dlxbn_2 = partial(import_gds, "sky130_fd_sc_hs__dlxbn_2.gds")
sky130_fd_sc_hs__dlxbp_1 = partial(import_gds, "sky130_fd_sc_hs__dlxbp_1.gds")
sky130_fd_sc_hs__dlxtn_1 = partial(import_gds, "sky130_fd_sc_hs__dlxtn_1.gds")
sky130_fd_sc_hs__dlxtn_2 = partial(import_gds, "sky130_fd_sc_hs__dlxtn_2.gds")
sky130_fd_sc_hs__dlxtn_4 = partial(import_gds, "sky130_fd_sc_hs__dlxtn_4.gds")
sky130_fd_sc_hs__dlxtp_1 = partial(import_gds, "sky130_fd_sc_hs__dlxtp_1.gds")
sky130_fd_sc_hs__dlygate4sd1_1 = partial(
    import_gds, "sky130_fd_sc_hs__dlygate4sd1_1.gds"
)
sky130_fd_sc_hs__dlygate4sd2_1 = partial(
    import_gds, "sky130_fd_sc_hs__dlygate4sd2_1.gds"
)
sky130_fd_sc_hs__dlygate4sd3_1 = partial(
    import_gds, "sky130_fd_sc_hs__dlygate4sd3_1.gds"
)
sky130_fd_sc_hs__dlymetal6s2s_1 = partial(
    import_gds, "sky130_fd_sc_hs__dlymetal6s2s_1.gds"
)
sky130_fd_sc_hs__dlymetal6s4s_1 = partial(
    import_gds, "sky130_fd_sc_hs__dlymetal6s4s_1.gds"
)
sky130_fd_sc_hs__dlymetal6s6s_1 = partial(
    import_gds, "sky130_fd_sc_hs__dlymetal6s6s_1.gds"
)
sky130_fd_sc_hs__ebufn_1 = partial(import_gds, "sky130_fd_sc_hs__ebufn_1.gds")
sky130_fd_sc_hs__ebufn_2 = partial(import_gds, "sky130_fd_sc_hs__ebufn_2.gds")
sky130_fd_sc_hs__ebufn_4 = partial(import_gds, "sky130_fd_sc_hs__ebufn_4.gds")
sky130_fd_sc_hs__ebufn_8 = partial(import_gds, "sky130_fd_sc_hs__ebufn_8.gds")
sky130_fd_sc_hs__edfxbp_1 = partial(import_gds, "sky130_fd_sc_hs__edfxbp_1.gds")
sky130_fd_sc_hs__edfxtp_1 = partial(import_gds, "sky130_fd_sc_hs__edfxtp_1.gds")
sky130_fd_sc_hs__einvn_1 = partial(import_gds, "sky130_fd_sc_hs__einvn_1.gds")
sky130_fd_sc_hs__einvn_2 = partial(import_gds, "sky130_fd_sc_hs__einvn_2.gds")
sky130_fd_sc_hs__einvn_4 = partial(import_gds, "sky130_fd_sc_hs__einvn_4.gds")
sky130_fd_sc_hs__einvn_8 = partial(import_gds, "sky130_fd_sc_hs__einvn_8.gds")
sky130_fd_sc_hs__einvp_1 = partial(import_gds, "sky130_fd_sc_hs__einvp_1.gds")
sky130_fd_sc_hs__einvp_2 = partial(import_gds, "sky130_fd_sc_hs__einvp_2.gds")
sky130_fd_sc_hs__einvp_4 = partial(import_gds, "sky130_fd_sc_hs__einvp_4.gds")
sky130_fd_sc_hs__einvp_8 = partial(import_gds, "sky130_fd_sc_hs__einvp_8.gds")
sky130_fd_sc_hs__fa_1 = partial(import_gds, "sky130_fd_sc_hs__fa_1.gds")
sky130_fd_sc_hs__fa_2 = partial(import_gds, "sky130_fd_sc_hs__fa_2.gds")
sky130_fd_sc_hs__fa_4 = partial(import_gds, "sky130_fd_sc_hs__fa_4.gds")
sky130_fd_sc_hs__fah_1 = partial(import_gds, "sky130_fd_sc_hs__fah_1.gds")
sky130_fd_sc_hs__fah_2 = partial(import_gds, "sky130_fd_sc_hs__fah_2.gds")
sky130_fd_sc_hs__fah_4 = partial(import_gds, "sky130_fd_sc_hs__fah_4.gds")
sky130_fd_sc_hs__fahcin_1 = partial(import_gds, "sky130_fd_sc_hs__fahcin_1.gds")
sky130_fd_sc_hs__fahcon_1 = partial(import_gds, "sky130_fd_sc_hs__fahcon_1.gds")
sky130_fd_sc_hs__fill_1 = partial(import_gds, "sky130_fd_sc_hs__fill_1.gds")
sky130_fd_sc_hs__fill_2 = partial(import_gds, "sky130_fd_sc_hs__fill_2.gds")
sky130_fd_sc_hs__fill_4 = partial(import_gds, "sky130_fd_sc_hs__fill_4.gds")
sky130_fd_sc_hs__fill_8 = partial(import_gds, "sky130_fd_sc_hs__fill_8.gds")
sky130_fd_sc_hs__fill_diode_2 = partial(import_gds, "sky130_fd_sc_hs__fill_diode_2.gds")
sky130_fd_sc_hs__fill_diode_4 = partial(import_gds, "sky130_fd_sc_hs__fill_diode_4.gds")
sky130_fd_sc_hs__fill_diode_8 = partial(import_gds, "sky130_fd_sc_hs__fill_diode_8.gds")
sky130_fd_sc_hs__ha_1 = partial(import_gds, "sky130_fd_sc_hs__ha_1.gds")
sky130_fd_sc_hs__ha_2 = partial(import_gds, "sky130_fd_sc_hs__ha_2.gds")
sky130_fd_sc_hs__ha_4 = partial(import_gds, "sky130_fd_sc_hs__ha_4.gds")
sky130_fd_sc_hs__inv_1 = partial(import_gds, "sky130_fd_sc_hs__inv_1.gds")
sky130_fd_sc_hs__inv_16 = partial(import_gds, "sky130_fd_sc_hs__inv_16.gds")
sky130_fd_sc_hs__inv_2 = partial(import_gds, "sky130_fd_sc_hs__inv_2.gds")
sky130_fd_sc_hs__inv_4 = partial(import_gds, "sky130_fd_sc_hs__inv_4.gds")
sky130_fd_sc_hs__inv_8 = partial(import_gds, "sky130_fd_sc_hs__inv_8.gds")
sky130_fd_sc_hs__maj3_1 = partial(import_gds, "sky130_fd_sc_hs__maj3_1.gds")
sky130_fd_sc_hs__maj3_2 = partial(import_gds, "sky130_fd_sc_hs__maj3_2.gds")
sky130_fd_sc_hs__maj3_4 = partial(import_gds, "sky130_fd_sc_hs__maj3_4.gds")
sky130_fd_sc_hs__mux2_1 = partial(import_gds, "sky130_fd_sc_hs__mux2_1.gds")
sky130_fd_sc_hs__mux2_2 = partial(import_gds, "sky130_fd_sc_hs__mux2_2.gds")
sky130_fd_sc_hs__mux2_4 = partial(import_gds, "sky130_fd_sc_hs__mux2_4.gds")
sky130_fd_sc_hs__mux2i_1 = partial(import_gds, "sky130_fd_sc_hs__mux2i_1.gds")
sky130_fd_sc_hs__mux2i_2 = partial(import_gds, "sky130_fd_sc_hs__mux2i_2.gds")
sky130_fd_sc_hs__mux2i_4 = partial(import_gds, "sky130_fd_sc_hs__mux2i_4.gds")
sky130_fd_sc_hs__mux4_1 = partial(import_gds, "sky130_fd_sc_hs__mux4_1.gds")
sky130_fd_sc_hs__mux4_2 = partial(import_gds, "sky130_fd_sc_hs__mux4_2.gds")
sky130_fd_sc_hs__mux4_4 = partial(import_gds, "sky130_fd_sc_hs__mux4_4.gds")
sky130_fd_sc_hs__nand2_1 = partial(import_gds, "sky130_fd_sc_hs__nand2_1.gds")
sky130_fd_sc_hs__nand2_2 = partial(import_gds, "sky130_fd_sc_hs__nand2_2.gds")
sky130_fd_sc_hs__nand2_4 = partial(import_gds, "sky130_fd_sc_hs__nand2_4.gds")
sky130_fd_sc_hs__nand2_8 = partial(import_gds, "sky130_fd_sc_hs__nand2_8.gds")
sky130_fd_sc_hs__nand2b_1 = partial(import_gds, "sky130_fd_sc_hs__nand2b_1.gds")
sky130_fd_sc_hs__nand2b_2 = partial(import_gds, "sky130_fd_sc_hs__nand2b_2.gds")
sky130_fd_sc_hs__nand2b_4 = partial(import_gds, "sky130_fd_sc_hs__nand2b_4.gds")
sky130_fd_sc_hs__nand3_1 = partial(import_gds, "sky130_fd_sc_hs__nand3_1.gds")
sky130_fd_sc_hs__nand3_2 = partial(import_gds, "sky130_fd_sc_hs__nand3_2.gds")
sky130_fd_sc_hs__nand3_4 = partial(import_gds, "sky130_fd_sc_hs__nand3_4.gds")
sky130_fd_sc_hs__nand3b_1 = partial(import_gds, "sky130_fd_sc_hs__nand3b_1.gds")
sky130_fd_sc_hs__nand3b_2 = partial(import_gds, "sky130_fd_sc_hs__nand3b_2.gds")
sky130_fd_sc_hs__nand3b_4 = partial(import_gds, "sky130_fd_sc_hs__nand3b_4.gds")
sky130_fd_sc_hs__nand4_1 = partial(import_gds, "sky130_fd_sc_hs__nand4_1.gds")
sky130_fd_sc_hs__nand4_2 = partial(import_gds, "sky130_fd_sc_hs__nand4_2.gds")
sky130_fd_sc_hs__nand4_4 = partial(import_gds, "sky130_fd_sc_hs__nand4_4.gds")
sky130_fd_sc_hs__nand4b_1 = partial(import_gds, "sky130_fd_sc_hs__nand4b_1.gds")
sky130_fd_sc_hs__nand4b_2 = partial(import_gds, "sky130_fd_sc_hs__nand4b_2.gds")
sky130_fd_sc_hs__nand4b_4 = partial(import_gds, "sky130_fd_sc_hs__nand4b_4.gds")
sky130_fd_sc_hs__nand4bb_1 = partial(import_gds, "sky130_fd_sc_hs__nand4bb_1.gds")
sky130_fd_sc_hs__nand4bb_2 = partial(import_gds, "sky130_fd_sc_hs__nand4bb_2.gds")
sky130_fd_sc_hs__nand4bb_4 = partial(import_gds, "sky130_fd_sc_hs__nand4bb_4.gds")
sky130_fd_sc_hs__nor2_1 = partial(import_gds, "sky130_fd_sc_hs__nor2_1.gds")
sky130_fd_sc_hs__nor2_2 = partial(import_gds, "sky130_fd_sc_hs__nor2_2.gds")
sky130_fd_sc_hs__nor2_4 = partial(import_gds, "sky130_fd_sc_hs__nor2_4.gds")
sky130_fd_sc_hs__nor2_8 = partial(import_gds, "sky130_fd_sc_hs__nor2_8.gds")
sky130_fd_sc_hs__nor2b_1 = partial(import_gds, "sky130_fd_sc_hs__nor2b_1.gds")
sky130_fd_sc_hs__nor2b_2 = partial(import_gds, "sky130_fd_sc_hs__nor2b_2.gds")
sky130_fd_sc_hs__nor2b_4 = partial(import_gds, "sky130_fd_sc_hs__nor2b_4.gds")
sky130_fd_sc_hs__nor3_1 = partial(import_gds, "sky130_fd_sc_hs__nor3_1.gds")
sky130_fd_sc_hs__nor3_2 = partial(import_gds, "sky130_fd_sc_hs__nor3_2.gds")
sky130_fd_sc_hs__nor3_4 = partial(import_gds, "sky130_fd_sc_hs__nor3_4.gds")
sky130_fd_sc_hs__nor3b_1 = partial(import_gds, "sky130_fd_sc_hs__nor3b_1.gds")
sky130_fd_sc_hs__nor3b_2 = partial(import_gds, "sky130_fd_sc_hs__nor3b_2.gds")
sky130_fd_sc_hs__nor3b_4 = partial(import_gds, "sky130_fd_sc_hs__nor3b_4.gds")
sky130_fd_sc_hs__nor4_1 = partial(import_gds, "sky130_fd_sc_hs__nor4_1.gds")
sky130_fd_sc_hs__nor4_2 = partial(import_gds, "sky130_fd_sc_hs__nor4_2.gds")
sky130_fd_sc_hs__nor4_4 = partial(import_gds, "sky130_fd_sc_hs__nor4_4.gds")
sky130_fd_sc_hs__nor4b_1 = partial(import_gds, "sky130_fd_sc_hs__nor4b_1.gds")
sky130_fd_sc_hs__nor4b_2 = partial(import_gds, "sky130_fd_sc_hs__nor4b_2.gds")
sky130_fd_sc_hs__nor4b_4 = partial(import_gds, "sky130_fd_sc_hs__nor4b_4.gds")
sky130_fd_sc_hs__nor4bb_1 = partial(import_gds, "sky130_fd_sc_hs__nor4bb_1.gds")
sky130_fd_sc_hs__nor4bb_2 = partial(import_gds, "sky130_fd_sc_hs__nor4bb_2.gds")
sky130_fd_sc_hs__nor4bb_4 = partial(import_gds, "sky130_fd_sc_hs__nor4bb_4.gds")
sky130_fd_sc_hs__o2111a_1 = partial(import_gds, "sky130_fd_sc_hs__o2111a_1.gds")
sky130_fd_sc_hs__o2111a_2 = partial(import_gds, "sky130_fd_sc_hs__o2111a_2.gds")
sky130_fd_sc_hs__o2111a_4 = partial(import_gds, "sky130_fd_sc_hs__o2111a_4.gds")
sky130_fd_sc_hs__o2111ai_1 = partial(import_gds, "sky130_fd_sc_hs__o2111ai_1.gds")
sky130_fd_sc_hs__o2111ai_2 = partial(import_gds, "sky130_fd_sc_hs__o2111ai_2.gds")
sky130_fd_sc_hs__o2111ai_4 = partial(import_gds, "sky130_fd_sc_hs__o2111ai_4.gds")
sky130_fd_sc_hs__o211a_1 = partial(import_gds, "sky130_fd_sc_hs__o211a_1.gds")
sky130_fd_sc_hs__o211a_2 = partial(import_gds, "sky130_fd_sc_hs__o211a_2.gds")
sky130_fd_sc_hs__o211a_4 = partial(import_gds, "sky130_fd_sc_hs__o211a_4.gds")
sky130_fd_sc_hs__o211ai_1 = partial(import_gds, "sky130_fd_sc_hs__o211ai_1.gds")
sky130_fd_sc_hs__o211ai_2 = partial(import_gds, "sky130_fd_sc_hs__o211ai_2.gds")
sky130_fd_sc_hs__o211ai_4 = partial(import_gds, "sky130_fd_sc_hs__o211ai_4.gds")
sky130_fd_sc_hs__o21a_1 = partial(import_gds, "sky130_fd_sc_hs__o21a_1.gds")
sky130_fd_sc_hs__o21a_2 = partial(import_gds, "sky130_fd_sc_hs__o21a_2.gds")
sky130_fd_sc_hs__o21a_4 = partial(import_gds, "sky130_fd_sc_hs__o21a_4.gds")
sky130_fd_sc_hs__o21ai_1 = partial(import_gds, "sky130_fd_sc_hs__o21ai_1.gds")
sky130_fd_sc_hs__o21ai_2 = partial(import_gds, "sky130_fd_sc_hs__o21ai_2.gds")
sky130_fd_sc_hs__o21ai_4 = partial(import_gds, "sky130_fd_sc_hs__o21ai_4.gds")
sky130_fd_sc_hs__o21ba_1 = partial(import_gds, "sky130_fd_sc_hs__o21ba_1.gds")
sky130_fd_sc_hs__o21ba_2 = partial(import_gds, "sky130_fd_sc_hs__o21ba_2.gds")
sky130_fd_sc_hs__o21ba_4 = partial(import_gds, "sky130_fd_sc_hs__o21ba_4.gds")
sky130_fd_sc_hs__o21bai_1 = partial(import_gds, "sky130_fd_sc_hs__o21bai_1.gds")
sky130_fd_sc_hs__o21bai_2 = partial(import_gds, "sky130_fd_sc_hs__o21bai_2.gds")
sky130_fd_sc_hs__o21bai_4 = partial(import_gds, "sky130_fd_sc_hs__o21bai_4.gds")
sky130_fd_sc_hs__o221a_1 = partial(import_gds, "sky130_fd_sc_hs__o221a_1.gds")
sky130_fd_sc_hs__o221a_2 = partial(import_gds, "sky130_fd_sc_hs__o221a_2.gds")
sky130_fd_sc_hs__o221a_4 = partial(import_gds, "sky130_fd_sc_hs__o221a_4.gds")
sky130_fd_sc_hs__o221ai_1 = partial(import_gds, "sky130_fd_sc_hs__o221ai_1.gds")
sky130_fd_sc_hs__o221ai_2 = partial(import_gds, "sky130_fd_sc_hs__o221ai_2.gds")
sky130_fd_sc_hs__o221ai_4 = partial(import_gds, "sky130_fd_sc_hs__o221ai_4.gds")
sky130_fd_sc_hs__o22a_1 = partial(import_gds, "sky130_fd_sc_hs__o22a_1.gds")
sky130_fd_sc_hs__o22a_2 = partial(import_gds, "sky130_fd_sc_hs__o22a_2.gds")
sky130_fd_sc_hs__o22a_4 = partial(import_gds, "sky130_fd_sc_hs__o22a_4.gds")
sky130_fd_sc_hs__o22ai_1 = partial(import_gds, "sky130_fd_sc_hs__o22ai_1.gds")
sky130_fd_sc_hs__o22ai_2 = partial(import_gds, "sky130_fd_sc_hs__o22ai_2.gds")
sky130_fd_sc_hs__o22ai_4 = partial(import_gds, "sky130_fd_sc_hs__o22ai_4.gds")
sky130_fd_sc_hs__o2bb2a_1 = partial(import_gds, "sky130_fd_sc_hs__o2bb2a_1.gds")
sky130_fd_sc_hs__o2bb2a_2 = partial(import_gds, "sky130_fd_sc_hs__o2bb2a_2.gds")
sky130_fd_sc_hs__o2bb2a_4 = partial(import_gds, "sky130_fd_sc_hs__o2bb2a_4.gds")
sky130_fd_sc_hs__o2bb2ai_1 = partial(import_gds, "sky130_fd_sc_hs__o2bb2ai_1.gds")
sky130_fd_sc_hs__o2bb2ai_2 = partial(import_gds, "sky130_fd_sc_hs__o2bb2ai_2.gds")
sky130_fd_sc_hs__o2bb2ai_4 = partial(import_gds, "sky130_fd_sc_hs__o2bb2ai_4.gds")
sky130_fd_sc_hs__o311a_1 = partial(import_gds, "sky130_fd_sc_hs__o311a_1.gds")
sky130_fd_sc_hs__o311a_2 = partial(import_gds, "sky130_fd_sc_hs__o311a_2.gds")
sky130_fd_sc_hs__o311a_4 = partial(import_gds, "sky130_fd_sc_hs__o311a_4.gds")
sky130_fd_sc_hs__o311ai_1 = partial(import_gds, "sky130_fd_sc_hs__o311ai_1.gds")
sky130_fd_sc_hs__o311ai_2 = partial(import_gds, "sky130_fd_sc_hs__o311ai_2.gds")
sky130_fd_sc_hs__o311ai_4 = partial(import_gds, "sky130_fd_sc_hs__o311ai_4.gds")
sky130_fd_sc_hs__o31a_1 = partial(import_gds, "sky130_fd_sc_hs__o31a_1.gds")
sky130_fd_sc_hs__o31a_2 = partial(import_gds, "sky130_fd_sc_hs__o31a_2.gds")
sky130_fd_sc_hs__o31a_4 = partial(import_gds, "sky130_fd_sc_hs__o31a_4.gds")
sky130_fd_sc_hs__o31ai_1 = partial(import_gds, "sky130_fd_sc_hs__o31ai_1.gds")
sky130_fd_sc_hs__o31ai_2 = partial(import_gds, "sky130_fd_sc_hs__o31ai_2.gds")
sky130_fd_sc_hs__o31ai_4 = partial(import_gds, "sky130_fd_sc_hs__o31ai_4.gds")
sky130_fd_sc_hs__o32a_1 = partial(import_gds, "sky130_fd_sc_hs__o32a_1.gds")
sky130_fd_sc_hs__o32a_2 = partial(import_gds, "sky130_fd_sc_hs__o32a_2.gds")
sky130_fd_sc_hs__o32a_4 = partial(import_gds, "sky130_fd_sc_hs__o32a_4.gds")
sky130_fd_sc_hs__o32ai_1 = partial(import_gds, "sky130_fd_sc_hs__o32ai_1.gds")
sky130_fd_sc_hs__o32ai_2 = partial(import_gds, "sky130_fd_sc_hs__o32ai_2.gds")
sky130_fd_sc_hs__o32ai_4 = partial(import_gds, "sky130_fd_sc_hs__o32ai_4.gds")
sky130_fd_sc_hs__o41a_1 = partial(import_gds, "sky130_fd_sc_hs__o41a_1.gds")
sky130_fd_sc_hs__o41a_2 = partial(import_gds, "sky130_fd_sc_hs__o41a_2.gds")
sky130_fd_sc_hs__o41a_4 = partial(import_gds, "sky130_fd_sc_hs__o41a_4.gds")
sky130_fd_sc_hs__o41ai_1 = partial(import_gds, "sky130_fd_sc_hs__o41ai_1.gds")
sky130_fd_sc_hs__o41ai_2 = partial(import_gds, "sky130_fd_sc_hs__o41ai_2.gds")
sky130_fd_sc_hs__o41ai_4 = partial(import_gds, "sky130_fd_sc_hs__o41ai_4.gds")
sky130_fd_sc_hs__or2_1 = partial(import_gds, "sky130_fd_sc_hs__or2_1.gds")
sky130_fd_sc_hs__or2_2 = partial(import_gds, "sky130_fd_sc_hs__or2_2.gds")
sky130_fd_sc_hs__or2_4 = partial(import_gds, "sky130_fd_sc_hs__or2_4.gds")
sky130_fd_sc_hs__or2b_1 = partial(import_gds, "sky130_fd_sc_hs__or2b_1.gds")
sky130_fd_sc_hs__or2b_2 = partial(import_gds, "sky130_fd_sc_hs__or2b_2.gds")
sky130_fd_sc_hs__or2b_4 = partial(import_gds, "sky130_fd_sc_hs__or2b_4.gds")
sky130_fd_sc_hs__or3_1 = partial(import_gds, "sky130_fd_sc_hs__or3_1.gds")
sky130_fd_sc_hs__or3_2 = partial(import_gds, "sky130_fd_sc_hs__or3_2.gds")
sky130_fd_sc_hs__or3_4 = partial(import_gds, "sky130_fd_sc_hs__or3_4.gds")
sky130_fd_sc_hs__or3b_1 = partial(import_gds, "sky130_fd_sc_hs__or3b_1.gds")
sky130_fd_sc_hs__or3b_2 = partial(import_gds, "sky130_fd_sc_hs__or3b_2.gds")
sky130_fd_sc_hs__or3b_4 = partial(import_gds, "sky130_fd_sc_hs__or3b_4.gds")
sky130_fd_sc_hs__or4_1 = partial(import_gds, "sky130_fd_sc_hs__or4_1.gds")
sky130_fd_sc_hs__or4_2 = partial(import_gds, "sky130_fd_sc_hs__or4_2.gds")
sky130_fd_sc_hs__or4_4 = partial(import_gds, "sky130_fd_sc_hs__or4_4.gds")
sky130_fd_sc_hs__or4b_1 = partial(import_gds, "sky130_fd_sc_hs__or4b_1.gds")
sky130_fd_sc_hs__or4b_2 = partial(import_gds, "sky130_fd_sc_hs__or4b_2.gds")
sky130_fd_sc_hs__or4b_4 = partial(import_gds, "sky130_fd_sc_hs__or4b_4.gds")
sky130_fd_sc_hs__or4bb_1 = partial(import_gds, "sky130_fd_sc_hs__or4bb_1.gds")
sky130_fd_sc_hs__or4bb_2 = partial(import_gds, "sky130_fd_sc_hs__or4bb_2.gds")
sky130_fd_sc_hs__or4bb_4 = partial(import_gds, "sky130_fd_sc_hs__or4bb_4.gds")
sky130_fd_sc_hs__sdfbbn_1 = partial(import_gds, "sky130_fd_sc_hs__sdfbbn_1.gds")
sky130_fd_sc_hs__sdfbbn_2 = partial(import_gds, "sky130_fd_sc_hs__sdfbbn_2.gds")
sky130_fd_sc_hs__sdfbbp_1 = partial(import_gds, "sky130_fd_sc_hs__sdfbbp_1.gds")
sky130_fd_sc_hs__sdfrbp_1 = partial(import_gds, "sky130_fd_sc_hs__sdfrbp_1.gds")
sky130_fd_sc_hs__sdfrbp_2 = partial(import_gds, "sky130_fd_sc_hs__sdfrbp_2.gds")
sky130_fd_sc_hs__sdfrtn_1 = partial(import_gds, "sky130_fd_sc_hs__sdfrtn_1.gds")
sky130_fd_sc_hs__sdfrtp_1 = partial(import_gds, "sky130_fd_sc_hs__sdfrtp_1.gds")
sky130_fd_sc_hs__sdfrtp_2 = partial(import_gds, "sky130_fd_sc_hs__sdfrtp_2.gds")
sky130_fd_sc_hs__sdfrtp_4 = partial(import_gds, "sky130_fd_sc_hs__sdfrtp_4.gds")
sky130_fd_sc_hs__sdfsbp_1 = partial(import_gds, "sky130_fd_sc_hs__sdfsbp_1.gds")
sky130_fd_sc_hs__sdfsbp_2 = partial(import_gds, "sky130_fd_sc_hs__sdfsbp_2.gds")
sky130_fd_sc_hs__sdfstp_1 = partial(import_gds, "sky130_fd_sc_hs__sdfstp_1.gds")
sky130_fd_sc_hs__sdfstp_2 = partial(import_gds, "sky130_fd_sc_hs__sdfstp_2.gds")
sky130_fd_sc_hs__sdfstp_4 = partial(import_gds, "sky130_fd_sc_hs__sdfstp_4.gds")
sky130_fd_sc_hs__sdfxbp_1 = partial(import_gds, "sky130_fd_sc_hs__sdfxbp_1.gds")
sky130_fd_sc_hs__sdfxbp_2 = partial(import_gds, "sky130_fd_sc_hs__sdfxbp_2.gds")
sky130_fd_sc_hs__sdfxtp_1 = partial(import_gds, "sky130_fd_sc_hs__sdfxtp_1.gds")
sky130_fd_sc_hs__sdfxtp_2 = partial(import_gds, "sky130_fd_sc_hs__sdfxtp_2.gds")
sky130_fd_sc_hs__sdfxtp_4 = partial(import_gds, "sky130_fd_sc_hs__sdfxtp_4.gds")
sky130_fd_sc_hs__sdlclkp_1 = partial(import_gds, "sky130_fd_sc_hs__sdlclkp_1.gds")
sky130_fd_sc_hs__sdlclkp_2 = partial(import_gds, "sky130_fd_sc_hs__sdlclkp_2.gds")
sky130_fd_sc_hs__sdlclkp_4 = partial(import_gds, "sky130_fd_sc_hs__sdlclkp_4.gds")
sky130_fd_sc_hs__sedfxbp_1 = partial(import_gds, "sky130_fd_sc_hs__sedfxbp_1.gds")
sky130_fd_sc_hs__sedfxbp_2 = partial(import_gds, "sky130_fd_sc_hs__sedfxbp_2.gds")
sky130_fd_sc_hs__sedfxtp_1 = partial(import_gds, "sky130_fd_sc_hs__sedfxtp_1.gds")
sky130_fd_sc_hs__sedfxtp_2 = partial(import_gds, "sky130_fd_sc_hs__sedfxtp_2.gds")
sky130_fd_sc_hs__sedfxtp_4 = partial(import_gds, "sky130_fd_sc_hs__sedfxtp_4.gds")
sky130_fd_sc_hs__tap_1 = partial(import_gds, "sky130_fd_sc_hs__tap_1.gds")
sky130_fd_sc_hs__tap_2 = partial(import_gds, "sky130_fd_sc_hs__tap_2.gds")
sky130_fd_sc_hs__tapmet1_2 = partial(import_gds, "sky130_fd_sc_hs__tapmet1_2.gds")
sky130_fd_sc_hs__tapvgnd2_1 = partial(import_gds, "sky130_fd_sc_hs__tapvgnd2_1.gds")
sky130_fd_sc_hs__tapvgnd_1 = partial(import_gds, "sky130_fd_sc_hs__tapvgnd_1.gds")
sky130_fd_sc_hs__tapvpwrvgnd_1 = partial(
    import_gds, "sky130_fd_sc_hs__tapvpwrvgnd_1.gds"
)
sky130_fd_sc_hs__xnor2_1 = partial(import_gds, "sky130_fd_sc_hs__xnor2_1.gds")
sky130_fd_sc_hs__xnor2_2 = partial(import_gds, "sky130_fd_sc_hs__xnor2_2.gds")
sky130_fd_sc_hs__xnor2_4 = partial(import_gds, "sky130_fd_sc_hs__xnor2_4.gds")
sky130_fd_sc_hs__xnor3_1 = partial(import_gds, "sky130_fd_sc_hs__xnor3_1.gds")
sky130_fd_sc_hs__xnor3_2 = partial(import_gds, "sky130_fd_sc_hs__xnor3_2.gds")
sky130_fd_sc_hs__xnor3_4 = partial(import_gds, "sky130_fd_sc_hs__xnor3_4.gds")
sky130_fd_sc_hs__xor2_1 = partial(import_gds, "sky130_fd_sc_hs__xor2_1.gds")
sky130_fd_sc_hs__xor2_2 = partial(import_gds, "sky130_fd_sc_hs__xor2_2.gds")
sky130_fd_sc_hs__xor2_4 = partial(import_gds, "sky130_fd_sc_hs__xor2_4.gds")
sky130_fd_sc_hs__xor3_1 = partial(import_gds, "sky130_fd_sc_hs__xor3_1.gds")
sky130_fd_sc_hs__xor3_2 = partial(import_gds, "sky130_fd_sc_hs__xor3_2.gds")
sky130_fd_sc_hs__xor3_4 = partial(import_gds, "sky130_fd_sc_hs__xor3_4.gds")
sky130_fd_sc_hvl__a21o_1 = partial(import_gds, "sky130_fd_sc_hvl__a21o_1.gds")
sky130_fd_sc_hvl__a21oi_1 = partial(import_gds, "sky130_fd_sc_hvl__a21oi_1.gds")
sky130_fd_sc_hvl__a22o_1 = partial(import_gds, "sky130_fd_sc_hvl__a22o_1.gds")
sky130_fd_sc_hvl__a22oi_1 = partial(import_gds, "sky130_fd_sc_hvl__a22oi_1.gds")
sky130_fd_sc_hvl__and2_1 = partial(import_gds, "sky130_fd_sc_hvl__and2_1.gds")
sky130_fd_sc_hvl__and3_1 = partial(import_gds, "sky130_fd_sc_hvl__and3_1.gds")
sky130_fd_sc_hvl__buf_1 = partial(import_gds, "sky130_fd_sc_hvl__buf_1.gds")
sky130_fd_sc_hvl__buf_16 = partial(import_gds, "sky130_fd_sc_hvl__buf_16.gds")
sky130_fd_sc_hvl__buf_2 = partial(import_gds, "sky130_fd_sc_hvl__buf_2.gds")
sky130_fd_sc_hvl__buf_32 = partial(import_gds, "sky130_fd_sc_hvl__buf_32.gds")
sky130_fd_sc_hvl__buf_4 = partial(import_gds, "sky130_fd_sc_hvl__buf_4.gds")
sky130_fd_sc_hvl__buf_8 = partial(import_gds, "sky130_fd_sc_hvl__buf_8.gds")
sky130_fd_sc_hvl__conb_1 = partial(import_gds, "sky130_fd_sc_hvl__conb_1.gds")
sky130_fd_sc_hvl__decap_4 = partial(import_gds, "sky130_fd_sc_hvl__decap_4.gds")
sky130_fd_sc_hvl__decap_8 = partial(import_gds, "sky130_fd_sc_hvl__decap_8.gds")
sky130_fd_sc_hvl__dfrbp_1 = partial(import_gds, "sky130_fd_sc_hvl__dfrbp_1.gds")
sky130_fd_sc_hvl__dfrtp_1 = partial(import_gds, "sky130_fd_sc_hvl__dfrtp_1.gds")
sky130_fd_sc_hvl__dfsbp_1 = partial(import_gds, "sky130_fd_sc_hvl__dfsbp_1.gds")
sky130_fd_sc_hvl__dfstp_1 = partial(import_gds, "sky130_fd_sc_hvl__dfstp_1.gds")
sky130_fd_sc_hvl__dfxbp_1 = partial(import_gds, "sky130_fd_sc_hvl__dfxbp_1.gds")
sky130_fd_sc_hvl__dfxtp_1 = partial(import_gds, "sky130_fd_sc_hvl__dfxtp_1.gds")
sky130_fd_sc_hvl__diode_2 = partial(import_gds, "sky130_fd_sc_hvl__diode_2.gds")
sky130_fd_sc_hvl__dlclkp_1 = partial(import_gds, "sky130_fd_sc_hvl__dlclkp_1.gds")
sky130_fd_sc_hvl__dlrtp_1 = partial(import_gds, "sky130_fd_sc_hvl__dlrtp_1.gds")
sky130_fd_sc_hvl__dlxtp_1 = partial(import_gds, "sky130_fd_sc_hvl__dlxtp_1.gds")
sky130_fd_sc_hvl__einvn_1 = partial(import_gds, "sky130_fd_sc_hvl__einvn_1.gds")
sky130_fd_sc_hvl__einvp_1 = partial(import_gds, "sky130_fd_sc_hvl__einvp_1.gds")
sky130_fd_sc_hvl__fill_1 = partial(import_gds, "sky130_fd_sc_hvl__fill_1.gds")
sky130_fd_sc_hvl__fill_2 = partial(import_gds, "sky130_fd_sc_hvl__fill_2.gds")
sky130_fd_sc_hvl__fill_4 = partial(import_gds, "sky130_fd_sc_hvl__fill_4.gds")
sky130_fd_sc_hvl__fill_8 = partial(import_gds, "sky130_fd_sc_hvl__fill_8.gds")
sky130_fd_sc_hvl__inv_1 = partial(import_gds, "sky130_fd_sc_hvl__inv_1.gds")
sky130_fd_sc_hvl__inv_16 = partial(import_gds, "sky130_fd_sc_hvl__inv_16.gds")
sky130_fd_sc_hvl__inv_2 = partial(import_gds, "sky130_fd_sc_hvl__inv_2.gds")
sky130_fd_sc_hvl__inv_4 = partial(import_gds, "sky130_fd_sc_hvl__inv_4.gds")
sky130_fd_sc_hvl__inv_8 = partial(import_gds, "sky130_fd_sc_hvl__inv_8.gds")
sky130_fd_sc_hvl__lsbufhv2hv_hl_1 = partial(
    import_gds, "sky130_fd_sc_hvl__lsbufhv2hv_hl_1.gds"
)
sky130_fd_sc_hvl__lsbufhv2hv_lh_1 = partial(
    import_gds, "sky130_fd_sc_hvl__lsbufhv2hv_lh_1.gds"
)
sky130_fd_sc_hvl__lsbufhv2lv_1 = partial(
    import_gds, "sky130_fd_sc_hvl__lsbufhv2lv_1.gds"
)
sky130_fd_sc_hvl__lsbufhv2lv_simple_1 = partial(
    import_gds, "sky130_fd_sc_hvl__lsbufhv2lv_simple_1.gds"
)
sky130_fd_sc_hvl__lsbuflv2hv_1 = partial(
    import_gds, "sky130_fd_sc_hvl__lsbuflv2hv_1.gds"
)
sky130_fd_sc_hvl__lsbuflv2hv_clkiso_hlkg_3 = partial(
    import_gds, "sky130_fd_sc_hvl__lsbuflv2hv_clkiso_hlkg_3.gds"
)
sky130_fd_sc_hvl__lsbuflv2hv_isosrchvaon_1 = partial(
    import_gds, "sky130_fd_sc_hvl__lsbuflv2hv_isosrchvaon_1.gds"
)
sky130_fd_sc_hvl__lsbuflv2hv_symmetric_1 = partial(
    import_gds, "sky130_fd_sc_hvl__lsbuflv2hv_symmetric_1.gds"
)
sky130_fd_sc_hvl__mux2_1 = partial(import_gds, "sky130_fd_sc_hvl__mux2_1.gds")
sky130_fd_sc_hvl__mux4_1 = partial(import_gds, "sky130_fd_sc_hvl__mux4_1.gds")
sky130_fd_sc_hvl__nand2_1 = partial(import_gds, "sky130_fd_sc_hvl__nand2_1.gds")
sky130_fd_sc_hvl__nand3_1 = partial(import_gds, "sky130_fd_sc_hvl__nand3_1.gds")
sky130_fd_sc_hvl__nor2_1 = partial(import_gds, "sky130_fd_sc_hvl__nor2_1.gds")
sky130_fd_sc_hvl__nor3_1 = partial(import_gds, "sky130_fd_sc_hvl__nor3_1.gds")
sky130_fd_sc_hvl__o21a_1 = partial(import_gds, "sky130_fd_sc_hvl__o21a_1.gds")
sky130_fd_sc_hvl__o21ai_1 = partial(import_gds, "sky130_fd_sc_hvl__o21ai_1.gds")
sky130_fd_sc_hvl__o22a_1 = partial(import_gds, "sky130_fd_sc_hvl__o22a_1.gds")
sky130_fd_sc_hvl__o22ai_1 = partial(import_gds, "sky130_fd_sc_hvl__o22ai_1.gds")
sky130_fd_sc_hvl__or2_1 = partial(import_gds, "sky130_fd_sc_hvl__or2_1.gds")
sky130_fd_sc_hvl__or3_1 = partial(import_gds, "sky130_fd_sc_hvl__or3_1.gds")
sky130_fd_sc_hvl__probe_p_8 = partial(import_gds, "sky130_fd_sc_hvl__probe_p_8.gds")
sky130_fd_sc_hvl__probec_p_8 = partial(import_gds, "sky130_fd_sc_hvl__probec_p_8.gds")
sky130_fd_sc_hvl__schmittbuf_1 = partial(
    import_gds, "sky130_fd_sc_hvl__schmittbuf_1.gds"
)
sky130_fd_sc_hvl__sdfrbp_1 = partial(import_gds, "sky130_fd_sc_hvl__sdfrbp_1.gds")
sky130_fd_sc_hvl__sdfrtp_1 = partial(import_gds, "sky130_fd_sc_hvl__sdfrtp_1.gds")
sky130_fd_sc_hvl__sdfsbp_1 = partial(import_gds, "sky130_fd_sc_hvl__sdfsbp_1.gds")
sky130_fd_sc_hvl__sdfstp_1 = partial(import_gds, "sky130_fd_sc_hvl__sdfstp_1.gds")
sky130_fd_sc_hvl__sdfxbp_1 = partial(import_gds, "sky130_fd_sc_hvl__sdfxbp_1.gds")
sky130_fd_sc_hvl__sdfxtp_1 = partial(import_gds, "sky130_fd_sc_hvl__sdfxtp_1.gds")
sky130_fd_sc_hvl__sdlclkp_1 = partial(import_gds, "sky130_fd_sc_hvl__sdlclkp_1.gds")
sky130_fd_sc_hvl__sdlxtp_1 = partial(import_gds, "sky130_fd_sc_hvl__sdlxtp_1.gds")
sky130_fd_sc_hvl__xnor2_1 = partial(import_gds, "sky130_fd_sc_hvl__xnor2_1.gds")
sky130_fd_sc_hvl__xor2_1 = partial(import_gds, "sky130_fd_sc_hvl__xor2_1.gds")


if __name__ == "__main__":
    # gf.write_cells.write_cells(gdspath=PATH.gdshd, dirpath="gds")
    # gf.write_cells.write_cells(gdspath=PATH.gdshs, dirpath="gds")
    # gf.write_cells.write_cells(gdspath=PATH.gdshvl, dirpath="gds")
    # print(gf.write_cells.get_import_gds_script(PATH.gds))
    # c = sky130_fd_sc_hvl__xor2_1()
    # c = sky130_fd_sc_hd__lpflow_lsbuf_lh_isowell_tap_2()
    c = sky130_fd_sc_hd__conb_1()
    c.show()



""" technology definitions """
import sys

import gdsfactory as gf
from gdsfactory.cross_section import get_cross_section_factories, strip

from sky130.layers import LAYER

xs_metal1 = gf.partial(strip, layer=LAYER.met1drawing, width=10.0)
xs_metal2 = gf.partial(strip, layer=LAYER.met2drawing, width=10.0)
strip = xs_metal1

cross_sections = get_cross_section_factories(sys.modules[__name__])


if __name__ == "__main__":
    print(cross_sections.keys())
